@@ -10,7 +10,7 @@ from fastapi.responses import JSONResponse
 from starlette.middleware.base import BaseHTTPMiddleware
 
 from mcp_proxy_adapter.core.transport_manager import transport_manager
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class TransportMiddleware(BaseHTTPMiddleware):
@@ -27,43 +27,6 @@ class TransportMiddleware(BaseHTTPMiddleware):
         super().__init__(app)
         self.transport_manager = transport_manager_instance or transport_manager
 
-    async def dispatch(self, request: Request, call_next: Callable) -> Response:
-        """
-        Process request through transport middleware.
-
-        Args:
-            request: Incoming request
-            call_next: Next middleware/endpoint
-
-        Returns:
-            Response from next middleware/endpoint or error response
-        """
-        # Determine transport type from request
-        transport_type = self._get_request_transport_type(request)
-
-        # Check if request matches configured transport
-        if not self._is_transport_allowed(transport_type):
-            configured_type = self.transport_manager.get_transport_type()
-            configured_type_str = (
-                configured_type.value if configured_type else "not configured"
-            )
-            logger.warning(f"Transport not allowed: {transport_type} for {request.url}")
-            return JSONResponse(
-                status_code=403,
-                content={
-                    "error": "Transport not allowed",
-                    "message": f"Transport '{transport_type}' is not allowed. Configured transport: {configured_type_str}",
-                    "configured_transport": configured_type_str,
-                    "request_url": str(request.url),
-                },
-            )
-
-        # Add transport info to request state
-        request.state.transport_type = transport_type
-        request.state.transport_allowed = True
-
-        response = await call_next(request)
-        return response
 
     def _get_request_transport_type(self, request: Request) -> str:
         """
@@ -118,7 +81,7 @@ class TransportMiddleware(BaseHTTPMiddleware):
         """
         configured_type = self.transport_manager.get_transport_type()
         if not configured_type:
-            logger.error("Transport not configured")
+            get_global_logger().error("Transport not configured")
             return False
 
         return transport_type == configured_type.value
