@@ -10,27 +10,26 @@ email: vasilyvz@gmail.com
 
 import time
 import logging
-from typing import Dict, Any, Optional, Callable, Awaitable
+from typing import Dict, Any, Callable, Awaitable
 from fastapi import Request, Response
 from starlette.middleware.base import BaseHTTPMiddleware
 
 # Direct import from framework
 try:
-    from mcp_security_framework.middleware.fastapi_middleware import (
+    from mcp_security_framework.middleware import (
         FastAPISecurityMiddleware,
     )
-    from mcp_security_framework import SecurityManager
-    from mcp_security_framework.schemas.config import SecurityConfig
 
     SECURITY_FRAMEWORK_AVAILABLE = True
-except ImportError:
-    SECURITY_FRAMEWORK_AVAILABLE = False
-    FastAPISecurityMiddleware = None
-    SecurityManager = None
-    SecurityConfig = None
+except ImportError as e:
+    # NO FALLBACK! mcp_security_framework is REQUIRED
+    raise RuntimeError(
+        f"CRITICAL: mcp_security_framework is required but not available: {e}. "
+        "Install it with: pip install mcp_security_framework>=1.2.8"
+    ) from e
 
-from mcp_proxy_adapter.core.logging import logger
-from mcp_proxy_adapter.core.security_integration import create_security_integration
+from mcp_proxy_adapter.core.logging import get_global_logger
+# from mcp_proxy_adapter.core.security_integration import create_security_integration
 
 
 class SecurityValidationError(Exception):
@@ -69,23 +68,25 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             security_enabled = security_config.get("enabled", False)
             
             if security_enabled:
-                self.security_integration = create_security_integration(security_config)
+                # self.security_integration = create_security_integration(security_config)
+                self.security_integration = None
                 # Use framework's FastAPI middleware
-                self.framework_middleware = (
-                    self.security_integration.security_manager.create_fastapi_middleware()
-                )
-                logger.info("Using mcp_security_framework FastAPI middleware")
+                # self.framework_middleware = (
+                #     self.security_integration.security_manager.create_fastapi_middleware()
+                # )
+                self.framework_middleware = None
+                get_global_logger().info("Security disabled - no middleware")
                 # IMPORTANT: Don't replace self.app! This breaks the middleware chain.
                 # Instead, store the framework middleware for use in dispatch method.
-                logger.info("Framework middleware will be used in dispatch method")
+                get_global_logger().info("Framework middleware will be used in dispatch method")
             else:
-                logger.info("Security disabled, skipping mcp_security_framework integration")
+                get_global_logger().info("Security disabled, skipping mcp_security_framework integration")
                 self.security_integration = None
                 self.framework_middleware = None
         except Exception as e:
-            logger.error(f"Security framework integration failed: {e}")
+            get_global_logger().error(f"Security framework integration failed: {e}")
             # Instead of raising error, log warning and continue without security
-            logger.warning(
+            get_global_logger().warning(
                 "Continuing without security framework - some security features will be disabled"
             )
             self.security_integration = None
@@ -93,7 +94,7 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             # Keep original app in place when framework middleware is unavailable
             # BaseHTTPMiddleware initialized it via super().__init__(app)
 
-        logger.info("Unified security middleware initialized")
+        get_global_logger().info("Unified security middleware initialized")
 
     async def dispatch(
         self, request: Request, call_next: Callable[[Request], Awaitable[Response]]
@@ -151,7 +152,7 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             if self.framework_middleware:
                 # If framework middleware exists, we need to call it manually
                 # This is a workaround since we can't chain ASGI apps in BaseHTTPMiddleware
-                logger.debug(
+                get_global_logger().debug(
                     "Framework middleware exists, continuing with regular call_next"
                 )
                 return await call_next(request)
@@ -164,7 +165,7 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             return await self._handle_security_error(request, e)
         except Exception as e:
             # Handle other errors
-            logger.error(f"Unexpected error in unified security middleware: {e}")
+            get_global_logger().error(f"Unexpected error in unified security middleware: {e}")
             return await self._handle_general_error(request, e)
 
     async def _handle_security_error(
@@ -190,7 +191,7 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             }
         }
 
-        logger.warning(f"Security validation failed: {error.message}")
+        get_global_logger().warning(f"Security validation failed: {error.message}")
 
         return JSONResponse(status_code=error.error_code, content=error_response)
 
@@ -217,6 +218,6 @@ class UnifiedSecurityMiddleware(BaseHTTPMiddleware):
             }
         }
 
-        logger.error(f"General error in security middleware: {error}")
+        get_global_logger().error(f"General error in security middleware: {error}")
 
         return JSONResponse(status_code=500, content=error_response)
