@@ -4,11 +4,10 @@ Base command classes for MCP Microservice.
 
 import inspect
 from abc import ABC, abstractmethod
-from typing import Any, ClassVar, Dict, List, Optional, Type, TypeVar
+from typing import TypeVar, Type, ClassVar, Dict, Any, List
 
 from docstring_parser import parse
 
-from mcp_proxy_adapter.commands.result import CommandResult, SuccessResult, ErrorResult
 from mcp_proxy_adapter.core.errors import (
     CommandError,
     InternalError,
@@ -16,7 +15,25 @@ from mcp_proxy_adapter.core.errors import (
     NotFoundError,
     ValidationError,
 )
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
+
+
+class CommandResult:
+    """Base class for command results."""
+    
+    def __init__(self, success: bool = True, data: dict = None, error: str = None):
+        self.success = success
+        self.data = data or {}
+        self.error = error
+    
+    def to_dict(self) -> dict:
+        """Convert to dictionary."""
+        result = {"success": self.success}
+        if self.data:
+            result["data"] = self.data
+        if self.error:
+            result["error"] = self.error
+        return result
 
 
 T = TypeVar("T", bound=CommandResult)
@@ -131,7 +148,7 @@ class Command(ABC):
 
             # Log warning about invalid parameters
             if invalid_params:
-                logger.warning(
+                get_global_logger().warning(
                     f"Command {self.__class__.__name__} received invalid parameters: {invalid_params}. "
                     f"Allowed parameters: {list(allowed_properties)}"
                 )
@@ -168,7 +185,7 @@ class Command(ABC):
         context = kwargs.pop("context", {}) if "context" in kwargs else {}
 
         try:
-            logger.debug(f"Running command {cls.__name__} with params: {kwargs}")
+            get_global_logger().debug(f"Running command {cls.__name__} with params: {kwargs}")
 
             # Import registry here to avoid circular imports
             from mcp_proxy_adapter.commands.command_registry import registry
@@ -197,31 +214,31 @@ class Command(ABC):
             # Execute command with validated parameters and context
             result = await command.execute(**validated_params, context=context)
 
-            logger.debug(f"Command {cls.__name__} executed successfully")
+            get_global_logger().debug(f"Command {cls.__name__} executed successfully")
             return result
         except ValidationError as e:
             # Ошибка валидации параметров
-            logger.error(f"Validation error in command {cls.__name__}: {e}")
+            get_global_logger().error(f"Validation error in command {cls.__name__}: {e}")
             return ErrorResult(message=str(e), code=e.code, details=e.data)
         except InvalidParamsError as e:
             # Ошибка в параметрах команды
-            logger.error(f"Invalid parameters error in command {cls.__name__}: {e}")
+            get_global_logger().error(f"Invalid parameters error in command {cls.__name__}: {e}")
             return ErrorResult(message=str(e), code=e.code, details=e.data)
         except NotFoundError as e:
             # Ресурс не найден
-            logger.error(f"Resource not found error in command {cls.__name__}: {e}")
+            get_global_logger().error(f"Resource not found error in command {cls.__name__}: {e}")
             return ErrorResult(message=str(e), code=e.code, details=e.data)
         except TimeoutError as e:
             # Превышено время ожидания
-            logger.error(f"Timeout error in command {cls.__name__}: {e}")
+            get_global_logger().error(f"Timeout error in command {cls.__name__}: {e}")
             return ErrorResult(message=str(e), code=e.code, details=e.data)
         except CommandError as e:
             # Ошибка выполнения команды
-            logger.error(f"Command error in {cls.__name__}: {e}")
+            get_global_logger().error(f"Command error in {cls.__name__}: {e}")
             return ErrorResult(message=str(e), code=e.code, details=e.data)
         except Exception as e:
             # Непредвиденная ошибка
-            logger.exception(f"Unexpected error executing command {cls.__name__}: {e}")
+            get_global_logger().exception(f"Unexpected error executing command {cls.__name__}: {e}")
             internal_error = InternalError(f"Command execution error: {str(e)}")
             return ErrorResult(
                 message=internal_error.message,
@@ -260,47 +277,6 @@ class Command(ABC):
         return params
 
     @classmethod
-    def get_metadata(cls) -> Dict[str, Any]:
-        """
-        Returns complete metadata about the command.
-
-        Provides a single access point to all command metadata.
-
-        Returns:
-            Dict with command metadata
-        """
-        # Get and format docstring
-        doc = cls.__doc__ or ""
-        description = inspect.cleandoc(doc) if doc else ""
-
-        # Extract first line for summary
-        summary = description.split("\n")[0] if description else ""
-
-        # Get parameters information
-        param_info = cls.get_param_info()
-
-        # Generate examples based on parameters
-        examples = cls._generate_examples(param_info)
-
-        return {
-            "name": cls.name,
-            "version": cls.version,
-            "plugin": cls.plugin,
-            "descr": cls.descr,
-            "category": cls.category,
-            "author": cls.author,
-            "email": cls.email,
-            "source_url": cls.source_url,
-            "summary": summary,
-            "description": description,
-            "params": param_info,
-            "examples": examples,
-            "schema": cls.get_schema(),
-            "result_schema": cls.get_result_schema(),
-            "result_class": (
-                cls.result_class.__name__ if hasattr(cls, "result_class") else None
-            ),
-        }
 
     @classmethod
     def _generate_examples(
