@@ -13,13 +13,13 @@ import os
 import json
 from typing import Dict, List, Optional, Any
 from pathlib import Path
-from datetime import datetime, timedelta
 
 from .base import Command
 from .result import CommandResult, SuccessResult, ErrorResult
 from ..core.certificate_utils import CertificateUtils
 from ..core.auth_validator import AuthValidator
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -66,77 +66,8 @@ class CertMonitorResult:
         self.auto_renewal_status = auto_renewal_status
         self.error = error
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "cert_path": self.cert_path,
-            "check_type": self.check_type,
-            "status": self.status,
-            "expiry_date": self.expiry_date,
-            "days_until_expiry": self.days_until_expiry,
-            "health_score": self.health_score,
-            "alerts": self.alerts,
-            "auto_renewal_status": self.auto_renewal_status,
-            "error": self.error,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for this result.
-
-        Returns:
-            JSON schema dictionary
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "cert_path": {
-                    "type": "string",
-                    "description": "Path to certificate file",
-                },
-                "check_type": {
-                    "type": "string",
-                    "enum": ["expiry", "health", "alert", "auto_renewal"],
-                    "description": "Type of check performed",
-                },
-                "status": {
-                    "type": "string",
-                    "enum": ["healthy", "warning", "critical", "error"],
-                    "description": "Overall status",
-                },
-                "expiry_date": {
-                    "type": "string",
-                    "description": "Certificate expiry date",
-                },
-                "days_until_expiry": {
-                    "type": "integer",
-                    "description": "Days until certificate expires",
-                },
-                "health_score": {
-                    "type": "integer",
-                    "minimum": 0,
-                    "maximum": 100,
-                    "description": "Health score (0-100)",
-                },
-                "alerts": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "List of alert messages",
-                },
-                "auto_renewal_status": {
-                    "type": "string",
-                    "description": "Auto-renewal status",
-                },
-                "error": {"type": "string", "description": "Error message if any"},
-            },
-            "required": ["cert_path", "check_type", "status"],
-        }
 
 
 class CertMonitorCommand(Command):
@@ -216,7 +147,7 @@ class CertMonitorCommand(Command):
             CommandResult with expiry check results
         """
         try:
-            logger.info(f"Performing certificate expiry check for {cert_path}")
+            get_global_logger().info(f"Performing certificate expiry check for {cert_path}")
 
             # Check if certificate file exists
             if not os.path.exists(cert_path):
@@ -255,7 +186,7 @@ class CertMonitorCommand(Command):
             else:
                 health_status = "healthy"
 
-            logger.info(
+            get_global_logger().info(
                 f"Certificate expiry check completed: {health_status} ({days_until_expiry} days)"
             )
 
@@ -273,7 +204,7 @@ class CertMonitorCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Certificate expiry check failed: {e}")
+            get_global_logger().error(f"Certificate expiry check failed: {e}")
             return ErrorResult(message=f"Certificate expiry check failed: {str(e)}")
 
     async def cert_health_check(self, cert_path: str) -> CommandResult:
@@ -287,7 +218,7 @@ class CertMonitorCommand(Command):
             CommandResult with health check results
         """
         try:
-            logger.info(f"Performing certificate health check for {cert_path}")
+            get_global_logger().info(f"Performing certificate health check for {cert_path}")
 
             # Check if certificate file exists
             if not os.path.exists(cert_path):
@@ -356,7 +287,7 @@ class CertMonitorCommand(Command):
             else:
                 overall_status = "critical"
 
-            logger.info(
+            get_global_logger().info(
                 f"Certificate health check completed: {overall_status} (score: {health_score})"
             )
 
@@ -373,7 +304,7 @@ class CertMonitorCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Certificate health check failed: {e}")
+            get_global_logger().error(f"Certificate health check failed: {e}")
             return ErrorResult(message=f"Certificate health check failed: {str(e)}")
 
     async def cert_alert_setup(
@@ -390,7 +321,7 @@ class CertMonitorCommand(Command):
             CommandResult with alert setup status
         """
         try:
-            logger.info(f"Setting up certificate monitoring alerts for {cert_path}")
+            get_global_logger().info(f"Setting up certificate monitoring alerts for {cert_path}")
 
             # Check if certificate file exists
             if not os.path.exists(cert_path):
@@ -444,7 +375,7 @@ class CertMonitorCommand(Command):
             with open(config_path, "w") as f:
                 json.dump(alert_config, f, indent=2)
 
-            logger.info(f"Alert configuration saved to {config_path}")
+            get_global_logger().info(f"Alert configuration saved to {config_path}")
 
             return SuccessResult(
                 data={
@@ -457,7 +388,7 @@ class CertMonitorCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Alert setup failed: {e}")
+            get_global_logger().error(f"Alert setup failed: {e}")
             return ErrorResult(message=f"Alert setup failed: {str(e)}")
 
     async def cert_auto_renew(
@@ -474,7 +405,7 @@ class CertMonitorCommand(Command):
             CommandResult with auto-renewal setup status
         """
         try:
-            logger.info(f"Setting up certificate auto-renewal for {cert_path}")
+            get_global_logger().info(f"Setting up certificate auto-renewal for {cert_path}")
 
             # Check if certificate file exists
             if not os.path.exists(cert_path):
@@ -533,7 +464,7 @@ class CertMonitorCommand(Command):
             with open(config_path, "w") as f:
                 json.dump(auto_renew_config, f, indent=2)
 
-            logger.info(f"Auto-renewal configuration saved to {config_path}")
+            get_global_logger().info(f"Auto-renewal configuration saved to {config_path}")
 
             return SuccessResult(
                 data={
@@ -546,27 +477,9 @@ class CertMonitorCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Auto-renewal setup failed: {e}")
+            get_global_logger().error(f"Auto-renewal setup failed: {e}")
             return ErrorResult(message=f"Auto-renewal setup failed: {str(e)}")
 
-    def _find_certificates(self, directory: str) -> List[str]:
-        """
-        Find all certificate files in a directory.
-
-        Args:
-            directory: Directory to scan
-
-        Returns:
-            List of certificate file paths
-        """
-        certificates = []
-        cert_extensions = [".crt", ".pem", ".cer", ".der"]
-
-        for file_path in Path(directory).rglob("*"):
-            if file_path.is_file() and file_path.suffix.lower() in cert_extensions:
-                certificates.append(str(file_path))
-
-        return certificates
 
     async def _test_alert_config(self, alert_config: Dict[str, Any]) -> Dict[str, Any]:
         """
