@@ -19,6 +19,7 @@ from ..core.certificate_utils import CertificateUtils
 from ..core.auth_validator import AuthValidator
 from ..core.role_utils import RoleUtils
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -81,51 +82,6 @@ class CertificateResult:
         }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for this result.
-
-        Returns:
-            JSON schema dictionary
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "cert_path": {
-                    "type": "string",
-                    "description": "Path to certificate file",
-                },
-                "cert_type": {
-                    "type": "string",
-                    "enum": ["CA", "server", "client"],
-                    "description": "Type of certificate",
-                },
-                "common_name": {
-                    "type": "string",
-                    "description": "Common name of certificate",
-                },
-                "roles": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "List of roles assigned to certificate",
-                },
-                "expiry_date": {
-                    "type": "string",
-                    "description": "Certificate expiry date",
-                },
-                "serial_number": {
-                    "type": "string",
-                    "description": "Certificate serial number",
-                },
-                "status": {
-                    "type": "string",
-                    "enum": ["valid", "expired", "revoked", "error"],
-                    "description": "Certificate status",
-                },
-                "error": {"type": "string", "description": "Error message if any"},
-            },
-            "required": ["cert_path", "cert_type", "common_name", "status"],
-        }
 
 
 class CertificateManagementCommand(Command):
@@ -236,7 +192,7 @@ class CertificateManagementCommand(Command):
             CommandResult with CA certificate creation status
         """
         try:
-            logger.info(f"Creating CA certificate: {common_name}")
+            get_global_logger().info(f"Creating CA certificate: {common_name}")
 
             # Validate parameters
             if not common_name or not common_name.strip():
@@ -276,7 +232,7 @@ class CertificateManagementCommand(Command):
                 status="valid",
             )
 
-            logger.info(
+            get_global_logger().info(
                 f"CA certificate created successfully: {result.get('cert_path')}"
             )
             return SuccessResult(
@@ -284,7 +240,7 @@ class CertificateManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"CA certificate creation failed: {e}")
+            get_global_logger().error(f"CA certificate creation failed: {e}")
             return ErrorResult(message=f"CA certificate creation failed: {str(e)}")
 
     async def cert_create_server(
@@ -311,7 +267,7 @@ class CertificateManagementCommand(Command):
             CommandResult with server certificate creation status
         """
         try:
-            logger.info(f"Creating server certificate: {common_name}")
+            get_global_logger().info(f"Creating server certificate: {common_name}")
 
             # Validate parameters
             if not common_name or not common_name.strip():
@@ -353,7 +309,7 @@ class CertificateManagementCommand(Command):
                 status="valid",
             )
 
-            logger.info(
+            get_global_logger().info(
                 f"Server certificate created successfully: {result.get('cert_path')}"
             )
             return SuccessResult(
@@ -361,7 +317,7 @@ class CertificateManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Server certificate creation failed: {e}")
+            get_global_logger().error(f"Server certificate creation failed: {e}")
             return ErrorResult(message=f"Server certificate creation failed: {str(e)}")
 
     async def cert_create_client(
@@ -388,7 +344,7 @@ class CertificateManagementCommand(Command):
             CommandResult with client certificate creation status
         """
         try:
-            logger.info(f"Creating client certificate: {common_name}")
+            get_global_logger().info(f"Creating client certificate: {common_name}")
 
             # Validate parameters
             if not common_name or not common_name.strip():
@@ -430,7 +386,7 @@ class CertificateManagementCommand(Command):
                 status="valid",
             )
 
-            logger.info(
+            get_global_logger().info(
                 f"Client certificate created successfully: {result.get('cert_path')}"
             )
             return SuccessResult(
@@ -438,7 +394,7 @@ class CertificateManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Client certificate creation failed: {e}")
+            get_global_logger().error(f"Client certificate creation failed: {e}")
             return ErrorResult(message=f"Client certificate creation failed: {str(e)}")
 
     async def cert_revoke(self, cert_path: str) -> CommandResult:
@@ -452,7 +408,7 @@ class CertificateManagementCommand(Command):
             CommandResult with revocation status
         """
         try:
-            logger.info(f"Revoking certificate: {cert_path}")
+            get_global_logger().info(f"Revoking certificate: {cert_path}")
 
             # Validate parameters
             if not cert_path or not os.path.exists(cert_path):
@@ -475,13 +431,13 @@ class CertificateManagementCommand(Command):
                 status="revoked",
             )
 
-            logger.info(f"Certificate revoked successfully: {cert_path}")
+            get_global_logger().info(f"Certificate revoked successfully: {cert_path}")
             return SuccessResult(
                 data={"certificate": cert_result.to_dict(), "revocation_result": result}
             )
 
         except Exception as e:
-            logger.error(f"Certificate revocation failed: {e}")
+            get_global_logger().error(f"Certificate revocation failed: {e}")
             return ErrorResult(message=f"Certificate revocation failed: {str(e)}")
 
     async def cert_list(self, cert_dir: str) -> CommandResult:
@@ -495,7 +451,7 @@ class CertificateManagementCommand(Command):
             CommandResult with list of certificates
         """
         try:
-            logger.info(f"Listing certificates in directory: {cert_dir}")
+            get_global_logger().info(f"Listing certificates in directory: {cert_dir}")
 
             # Validate parameters
             if not cert_dir or not os.path.exists(cert_dir):
@@ -526,7 +482,7 @@ class CertificateManagementCommand(Command):
                             )
                             certificates.append(cert_result.to_dict())
                     except Exception as e:
-                        logger.warning(f"Could not read certificate {file_path}: {e}")
+                        get_global_logger().warning(f"Could not read certificate {file_path}: {e}")
                         # Add certificate with error status
                         cert_result = CertificateResult(
                             cert_path=str(file_path),
@@ -537,7 +493,7 @@ class CertificateManagementCommand(Command):
                         )
                         certificates.append(cert_result.to_dict())
 
-            logger.info(f"Found {len(certificates)} certificates in {cert_dir}")
+            get_global_logger().info(f"Found {len(certificates)} certificates in {cert_dir}")
             return SuccessResult(
                 data={
                     "certificates": certificates,
@@ -547,7 +503,7 @@ class CertificateManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Certificate listing failed: {e}")
+            get_global_logger().error(f"Certificate listing failed: {e}")
             return ErrorResult(message=f"Certificate listing failed: {str(e)}")
 
     async def cert_info(self, cert_path: str) -> CommandResult:
@@ -561,7 +517,7 @@ class CertificateManagementCommand(Command):
             CommandResult with certificate information
         """
         try:
-            logger.info(f"Getting certificate info: {cert_path}")
+            get_global_logger().info(f"Getting certificate info: {cert_path}")
 
             # Validate parameters
             if not cert_path or not os.path.exists(cert_path):
@@ -587,7 +543,7 @@ class CertificateManagementCommand(Command):
                 error=None if validation.is_valid else validation.error_message,
             )
 
-            logger.info(f"Certificate info retrieved successfully: {cert_path}")
+            get_global_logger().info(f"Certificate info retrieved successfully: {cert_path}")
             return SuccessResult(
                 data={
                     "certificate": cert_result.to_dict(),
@@ -602,5 +558,5 @@ class CertificateManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Certificate info retrieval failed: {e}")
+            get_global_logger().error(f"Certificate info retrieval failed: {e}")
             return ErrorResult(message=f"Certificate info retrieval failed: {str(e)}")
