@@ -6,7 +6,7 @@ from typing import Dict, Any, Optional
 
 from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.result import SuccessResult
-from mcp_proxy_adapter.config import config as config_instance
+from mcp_proxy_adapter.config import get_config
 
 
 class ConfigResult(SuccessResult):
@@ -67,6 +67,7 @@ class ConfigCommand(Command):
         result_config = {}
 
         if operation == "get":
+            config_instance = get_config()
             if path:
                 # Get specific config value
                 result_config = {path: config_instance.get(path)}
@@ -78,6 +79,7 @@ class ConfigCommand(Command):
         elif operation == "set":
             if path and value is not None:
                 # Set config value
+                config_instance = get_config()
                 config_instance.set(path, value)
                 # Save config
                 config_instance.save()
@@ -98,31 +100,3 @@ class ConfigCommand(Command):
         return ConfigResult(config=result_config, operation=operation, message=message)
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Returns JSON schema for command parameters validation.
-
-        Returns:
-            Dictionary with JSON schema.
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "operation": {
-                    "type": "string",
-                    "enum": ["get", "set"],
-                    "default": "get",
-                    "description": "Operation to perform (get or set)",
-                },
-                "path": {
-                    "type": "string",
-                    "description": "Configuration path in dot notation "
-                    "(e.g. 'server.host')",
-                },
-                "value": {
-                    "description": "Value to set (required for " "'set' operation)"
-                },
-            },
-            "required": ["operation"],
-            "additionalProperties": False,
-        }
