@@ -7,10 +7,8 @@ import platform
 import sys
 import psutil
 from datetime import datetime
-from typing import Dict, Any, Optional
 
 from mcp_proxy_adapter.commands.base import Command
-from mcp_proxy_adapter.commands.result import CommandResult, SuccessResult
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.core.proxy_registration import get_proxy_registration_status
 
@@ -91,7 +89,6 @@ class HealthCommand(Command):
         """
         # Get version from package
         try:
-            from mcp_proxy_adapter.version import __version__ as version
         except ImportError:
             version = "unknown"
 
