@@ -11,7 +11,6 @@ Version: 1.0.0
 import logging
 import os
 import shutil
-from typing import Dict, List, Optional, Any
 from pathlib import Path
 from datetime import datetime
 
@@ -19,6 +18,7 @@ from .base import Command
 from .result import CommandResult, SuccessResult, ErrorResult
 from ..core.certificate_utils import CertificateUtils
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -77,30 +77,6 @@ class KeyResult:
         }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for this result.
-
-        Returns:
-            JSON schema dictionary
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "key_path": {"type": "string", "description": "Path to key file"},
-                "key_type": {"type": "string", "description": "Type of key"},
-                "key_size": {"type": "integer", "description": "Key size in bits"},
-                "created_date": {"type": "string", "description": "Key creation date"},
-                "expiry_date": {"type": "string", "description": "Key expiry date"},
-                "status": {
-                    "type": "string",
-                    "enum": ["valid", "expired", "error"],
-                    "description": "Key status",
-                },
-                "error": {"type": "string", "description": "Error message if any"},
-            },
-            "required": ["key_path", "key_type", "key_size", "status"],
-        }
 
 
 class KeyManagementCommand(Command):
@@ -205,7 +181,7 @@ class KeyManagementCommand(Command):
             CommandResult with key generation status
         """
         try:
-            logger.info(f"Generating {key_type} key with size {key_size} bits")
+            get_global_logger().info(f"Generating {key_type} key with size {key_size} bits")
 
             # Validate parameters
             if key_type not in ["RSA", "ECDSA"]:
@@ -240,11 +216,11 @@ class KeyManagementCommand(Command):
                 status="valid",
             )
 
-            logger.info(f"Key generated successfully: {output_path}")
+            get_global_logger().info(f"Key generated successfully: {output_path}")
             return SuccessResult(data={"key": key_result.to_dict(), "details": result})
 
         except Exception as e:
-            logger.error(f"Key generation failed: {e}")
+            get_global_logger().error(f"Key generation failed: {e}")
             return ErrorResult(message=f"Key generation failed: {str(e)}")
 
     async def key_validate(
@@ -261,7 +237,7 @@ class KeyManagementCommand(Command):
             CommandResult with key validation status
         """
         try:
-            logger.info(f"Validating key: {key_path}")
+            get_global_logger().info(f"Validating key: {key_path}")
 
             # Validate parameters
             if not key_path or not os.path.exists(key_path):
@@ -281,11 +257,11 @@ class KeyManagementCommand(Command):
                 status="valid",
             )
 
-            logger.info(f"Key validation completed: {key_path}")
+            get_global_logger().info(f"Key validation completed: {key_path}")
             return SuccessResult(data={"key": key_result.to_dict()})
 
         except Exception as e:
-            logger.error(f"Key validation failed: {e}")
+            get_global_logger().error(f"Key validation failed: {e}")
             return ErrorResult(message=f"Key validation failed: {str(e)}")
 
     async def key_rotate(
@@ -308,7 +284,7 @@ class KeyManagementCommand(Command):
             CommandResult with key rotation status
         """
         try:
-            logger.info(f"Rotating key from {old_key_path} to {new_key_path}")
+            get_global_logger().info(f"Rotating key from {old_key_path} to {new_key_path}")
 
             # Validate parameters
             if not old_key_path or not os.path.exists(old_key_path):
@@ -338,7 +314,7 @@ class KeyManagementCommand(Command):
                     f"{old_key_path}.backup.{datetime.now().strftime('%Y%m%d_%H%M%S')}"
                 )
                 shutil.copy2(old_key_path, backup_path)
-                logger.info(f"Old key backed up to: {backup_path}")
+                get_global_logger().info(f"Old key backed up to: {backup_path}")
 
             # Update certificate if provided
             cert_updated = False
@@ -347,16 +323,16 @@ class KeyManagementCommand(Command):
                     # This would require implementing certificate re-signing
                     # For now, we'll just note that it needs to be done
                     cert_updated = True
-                    logger.info(
+                    get_global_logger().info(
                         f"Certificate {cert_path} needs to be re-signed with new key"
                     )
                 except Exception as e:
-                    logger.warning(f"Could not update certificate {cert_path}: {e}")
+                    get_global_logger().warning(f"Could not update certificate {cert_path}: {e}")
 
             # Replace old key with new key
             shutil.copy2(new_key_path, old_key_path)
 
-            logger.info(f"Key rotation completed successfully")
+            get_global_logger().info(f"Key rotation completed successfully")
             return SuccessResult(
                 data={
                     "old_key_path": old_key_path,
@@ -368,7 +344,7 @@ class KeyManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Key rotation failed: {e}")
+            get_global_logger().error(f"Key rotation failed: {e}")
             return ErrorResult(message=f"Key rotation failed: {str(e)}")
 
     async def key_backup(
@@ -391,7 +367,7 @@ class KeyManagementCommand(Command):
             CommandResult with backup status
         """
         try:
-            logger.info(f"Backing up key: {key_path}")
+            get_global_logger().info(f"Backing up key: {key_path}")
 
             # Validate parameters
             if not key_path or not os.path.exists(key_path):
@@ -427,7 +403,7 @@ class KeyManagementCommand(Command):
             if not os.path.exists(backup_path):
                 return ErrorResult(message="Backup file was not created")
 
-            logger.info(f"Key backup completed successfully: {backup_path}")
+            get_global_logger().info(f"Key backup completed successfully: {backup_path}")
             return SuccessResult(
                 data={
                     "key_path": key_path,
@@ -439,7 +415,7 @@ class KeyManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Key backup failed: {e}")
+            get_global_logger().error(f"Key backup failed: {e}")
             return ErrorResult(message=f"Key backup failed: {str(e)}")
 
     async def key_restore(
@@ -457,7 +433,7 @@ class KeyManagementCommand(Command):
             CommandResult with restore status
         """
         try:
-            logger.info(f"Restoring key from backup: {backup_path}")
+            get_global_logger().info(f"Restoring key from backup: {backup_path}")
 
             # Validate parameters
             if not backup_path or not os.path.exists(backup_path):
@@ -489,7 +465,7 @@ class KeyManagementCommand(Command):
                     message=f"Restored key validation failed: {key_validation.to_dict()['error']['message']}"
                 )
 
-            logger.info(f"Key restore completed successfully: {key_path}")
+            get_global_logger().info(f"Key restore completed successfully: {key_path}")
             return SuccessResult(
                 data={
                     "backup_path": backup_path,
@@ -504,5 +480,5 @@ class KeyManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Key restore failed: {e}")
+            get_global_logger().error(f"Key restore failed: {e}")
             return ErrorResult(message=f"Key restore failed: {str(e)}")
