@@ -5,8 +5,8 @@ Module with load command implementation.
 from typing import Dict, Any, Optional, List
 
 from mcp_proxy_adapter.commands.base import Command
-from mcp_proxy_adapter.commands.result import CommandResult, SuccessResult
 from mcp_proxy_adapter.commands.command_registry import registry
+from mcp_proxy_adapter.commands.result import SuccessResult
 
 
 class LoadResult(SuccessResult):
@@ -49,36 +49,15 @@ class LoadResult(SuccessResult):
 
     @classmethod
     def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result validation.
-
-        Returns:
-            Dict[str, Any]: JSON schema
-        """
         return {
             "type": "object",
             "properties": {
-                "data": {
-                    "type": "object",
-                    "properties": {
-                        "success": {"type": "boolean"},
-                        "commands_loaded": {"type": "integer"},
-                        "loaded_commands": {
-                            "type": "array",
-                            "items": {"type": "string"},
-                        },
-                        "source": {"type": "string"},
-                        "error": {"type": "string"},
-                    },
-                    "required": [
-                        "success",
-                        "commands_loaded",
-                        "loaded_commands",
-                        "source",
-                    ],
-                }
+                "success": {"type": "boolean"},
+                "commands_loaded": {"type": "integer"},
+                "loaded_commands": {"type": "array", "items": {"type": "string"}},
+                "source": {"type": "string"},
+                "error": {"type": "string"},
             },
-            "required": ["data"],
         }
 
 
@@ -135,60 +114,10 @@ class LoadCommand(Command):
 
     @classmethod
     def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for command parameters.
-
-        Returns:
-            Dict[str, Any]: JSON schema
-        """
         return {
             "type": "object",
             "properties": {
-                "source": {
-                    "type": "string",
-                    "description": "Source path or URL to load command from (must end with '_command.py')",
-                    "examples": [
-                        "./my_command.py",
-                        "https://example.com/remote_command.py",
-                    ],
-                }
+                "source": {"type": "string", "description": "Path or URL to command file"}
             },
             "required": ["source"],
         }
-
-    @classmethod
-    def _generate_examples(
-        cls, params: Dict[str, Dict[str, Any]]
-    ) -> List[Dict[str, Any]]:
-        """
-        Generate custom examples for load command.
-
-        Args:
-            params: Information about command parameters
-
-        Returns:
-            List of examples
-        """
-        examples = [
-            {
-                "command": cls.name,
-                "params": {"source": "./custom_command.py"},
-                "description": "Load a command from local file system",
-            },
-            {
-                "command": cls.name,
-                "params": {
-                    "source": "https://raw.githubusercontent.com/user/repo/main/remote_command.py"
-                },
-                "description": "Load a command from GitHub raw content",
-            },
-            {
-                "command": cls.name,
-                "params": {
-                    "source": "https://example.com/api/commands/test_command.py"
-                },
-                "description": "Load a command from remote API endpoint",
-            },
-        ]
-
-        return examples
