@@ -5,9 +5,8 @@ Module with plugins command implementation.
 from typing import Dict, Any, Optional, List
 
 from mcp_proxy_adapter.commands.base import Command
-from mcp_proxy_adapter.commands.result import CommandResult, SuccessResult
 from mcp_proxy_adapter.commands.command_registry import registry
-from mcp_proxy_adapter.config import config as config_instance
+from mcp_proxy_adapter.config import get_config
 
 
 class PluginsResult(SuccessResult):
@@ -141,6 +140,7 @@ class PluginsCommand(Command):
         """
         try:
             # Get configuration from the global config instance
+            config_instance = get_config()
             plugins_server_url = config_instance.get("commands.plugins_server")
 
             if not plugins_server_url:
@@ -218,21 +218,6 @@ class PluginsCommand(Command):
             )
 
     @classmethod
-    def get_metadata(cls) -> Dict[str, Any]:
-        """
-        Get command metadata.
-
-        Returns:
-            Dict[str, Any]: Command metadata
-        """
-        return {
-            "name": cls.name,
-            "summary": "Command that reads and displays available plugins from a plugins server",
-            "description": cls.__doc__,
-            "parameters": {},
-            "examples": cls._generate_examples({}),
-            "schema": cls.result_class.get_schema(),
-        }
 
     @classmethod
     def _generate_examples(
