@@ -11,7 +11,7 @@ from dataclasses import dataclass
 from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.result import SuccessResult, ErrorResult
 from mcp_proxy_adapter.core.protocol_manager import protocol_manager
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 @dataclass
@@ -52,34 +52,6 @@ class ProtocolManagementCommand(Command):
     descr = "Manage and query protocol configurations (HTTP, HTTPS, MTLS)"
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get command schema.
-
-        Returns:
-            Command schema dictionary
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "action": {
-                    "type": "string",
-                    "enum": [
-                        "get_info",
-                        "validate_config",
-                        "get_allowed",
-                        "check_protocol",
-                    ],
-                    "description": "Action to perform",
-                },
-                "protocol": {
-                    "type": "string",
-                    "enum": ["http", "https", "mtls"],
-                    "description": "Protocol to check (for check_protocol action)",
-                },
-            },
-            "required": ["action"],
-        }
 
     async def execute(self, **kwargs) -> SuccessResult | ErrorResult:
         """
@@ -112,7 +84,7 @@ class ProtocolManagementCommand(Command):
                 return ErrorResult(f"Unknown action: {action}")
 
         except Exception as e:
-            logger.error(f"Protocol management command error: {e}")
+            get_global_logger().error(f"Protocol management command error: {e}")
             return ErrorResult(f"Protocol management error: {str(e)}")
 
     async def _get_protocol_info(self) -> SuccessResult:
@@ -150,7 +122,7 @@ class ProtocolManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Error getting protocol info: {e}")
+            get_global_logger().error(f"Error getting protocol info: {e}")
             return ErrorResult(f"Failed to get protocol info: {str(e)}")
 
     async def _validate_configuration(self) -> SuccessResult:
@@ -174,7 +146,7 @@ class ProtocolManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Error validating configuration: {e}")
+            get_global_logger().error(f"Error validating configuration: {e}")
             return ErrorResult(f"Failed to validate configuration: {str(e)}")
 
     async def _get_allowed_protocols(self) -> SuccessResult:
@@ -196,7 +168,7 @@ class ProtocolManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Error getting allowed protocols: {e}")
+            get_global_logger().error(f"Error getting allowed protocols: {e}")
             return ErrorResult(f"Failed to get allowed protocols: {str(e)}")
 
     async def _check_protocol(self, protocol: str) -> SuccessResult:
@@ -240,5 +212,5 @@ class ProtocolManagementCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Error checking protocol {protocol}: {e}")
+            get_global_logger().error(f"Error checking protocol {protocol}: {e}")
             return ErrorResult(f"Failed to check protocol {protocol}: {str(e)}")
