@@ -10,13 +10,12 @@ email: vasilyvz@gmail.com
 
 import json
 import time
-import uuid
 from typing import Dict, Any, List, Optional
 from dataclasses import dataclass
 
 from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.result import SuccessResult
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 @dataclass
@@ -29,42 +28,8 @@ class ProxyRegistrationCommandResult(SuccessResult):
     message: str = ""
     details: Optional[Dict[str, Any]] = None
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert result to dictionary."""
-        result = {
-            "operation": self.operation,
-            "success": self.success,
-            "message": self.message,
-        }
-
-        if self.server_key:
-            result["server_key"] = self.server_key
-
-        if self.details:
-            result["details"] = self.details
-
-        return result
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get JSON schema for result."""
-        return {
-            "type": "object",
-            "properties": {
-                "operation": {"type": "string", "description": "Operation performed"},
-                "success": {
-                    "type": "boolean",
-                    "description": "Whether operation was successful",
-                },
-                "server_key": {
-                    "type": "string",
-                    "description": "Server key for registered server",
-                },
-                "message": {"type": "string", "description": "Result message"},
-                "details": {"type": "object", "description": "Additional details"},
-            },
-            "required": ["operation", "success", "message"],
-        }
 
 
 class ProxyRegistrationCommand(Command):
@@ -120,19 +85,25 @@ class ProxyRegistrationCommand(Command):
 
         required_permissions = operation_permissions.get(operation, ["read"])
 
-        # Check if user has required permissions
-        logger.info(
-            f"Checking permissions: user_permissions={user_permissions}, required={required_permissions}"
-        )
-        if not self._check_permissions(user_permissions, required_permissions):
-            return ProxyRegistrationCommandResult(
-                operation=operation,
-                success=False,
-                message=f"Permission denied: {operation} requires {required_permissions}",
+        # Check if security is enabled before checking permissions
+        security_enabled = self.config.get("security", {}).get("enabled", False)
+        
+        # Only check permissions if security is enabled
+        if security_enabled:
+            get_global_logger().info(
+                f"Checking permissions: user_permissions={user_permissions}, required={required_permissions}"
             )
+            if not self._check_permissions(user_permissions, required_permissions):
+                return ProxyRegistrationCommandResult(
+                    operation=operation,
+                    success=False,
+                    message=f"Permission denied: {operation} requires {required_permissions}",
+                )
+        else:
+            get_global_logger().debug(f"Security disabled, skipping permission check for operation: {operation}")
 
-        logger.info(f"Executing proxy registration operation: {operation}")
-        logger.debug(
+        get_global_logger().info(f"Executing proxy registration operation: {operation}")
+        get_global_logger().debug(
             f"User permissions: {user_permissions}, required: {required_permissions}"
         )
 
@@ -197,7 +168,7 @@ class ProxyRegistrationCommand(Command):
 
         self._registry[server_key] = server_record
 
-        logger.info(f"Registered server: {server_key} at {server_url}")
+        get_global_logger().info(f"Registered server: {server_key} at {server_url}")
 
         return ProxyRegistrationCommandResult(
             operation="register",
@@ -229,7 +200,7 @@ class ProxyRegistrationCommand(Command):
 
         if server_key in self._registry:
             del self._registry[server_key]
-            logger.info(f"Unregistered server: {server_key}")
+            get_global_logger().info(f"Unregistered server: {server_key}")
 
             return ProxyRegistrationCommandResult(
                 operation="unregister",
@@ -265,7 +236,7 @@ class ProxyRegistrationCommand(Command):
             self._registry[server_key]["last_heartbeat"] = timestamp
             self._registry[server_key]["status"] = status
 
-            logger.debug(f"Heartbeat received for server: {server_key}")
+            get_global_logger().debug(f"Heartbeat received for server: {server_key}")
 
             return ProxyRegistrationCommandResult(
                 operation="heartbeat",
@@ -312,7 +283,7 @@ class ProxyRegistrationCommand(Command):
                 }
                 proxies.append(proxy_info)
 
-        logger.info(f"Discovery request returned {len(proxies)} active servers")
+        get_global_logger().info(f"Discovery request returned {len(proxies)} active servers")
 
         return ProxyRegistrationCommandResult(
             operation="discover",
@@ -346,56 +317,3 @@ class ProxyRegistrationCommand(Command):
         return True
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get JSON schema for command parameters."""
-        return {
-            "type": "object",
-            "properties": {
-                "operation": {
-                    "type": "string",
-                    "enum": ["register", "unregister", "heartbeat", "discover"],
-                    "description": "Operation to perform",
-                    "default": "register",
-                },
-                "server_id": {
-                    "type": "string",
-                    "description": "Server ID for registration",
-                },
-                "server_url": {
-                    "type": "string",
-                    "description": "Server URL for registration",
-                },
-                "server_name": {"type": "string", "description": "Server name"},
-                "description": {"type": "string", "description": "Server description"},
-                "version": {"type": "string", "description": "Server version"},
-                "capabilities": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "Server capabilities",
-                },
-                "endpoints": {"type": "object", "description": "Server endpoints"},
-                "auth_method": {
-                    "type": "string",
-                    "description": "Authentication method",
-                },
-                "security_enabled": {
-                    "type": "boolean",
-                    "description": "Whether security is enabled",
-                },
-                "server_key": {
-                    "type": "string",
-                    "description": "Server key for unregistration/heartbeat",
-                },
-                "copy_number": {
-                    "type": "integer",
-                    "description": "Copy number for unregistration",
-                },
-                "timestamp": {
-                    "type": "integer",
-                    "description": "Timestamp for heartbeat",
-                },
-                "status": {"type": "string", "description": "Status for heartbeat"},
-            },
-            "required": ["operation"],
-            "additionalProperties": False,
-        }
