@@ -9,7 +9,7 @@ from typing import Any, Dict, Optional
 
 from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.command_registry import registry
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class ReloadResult:
@@ -73,68 +73,6 @@ class ReloadResult:
         }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for the result.
-
-        Returns:
-            JSON schema dictionary.
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {
-                    "type": "boolean",
-                    "description": "Whether reload was successful",
-                },
-                "config_reloaded": {
-                    "type": "boolean",
-                    "description": "Whether configuration was reloaded successfully",
-                },
-                "builtin_commands": {
-                    "type": "integer",
-                    "description": "Number of built-in commands registered",
-                },
-                "custom_commands": {
-                    "type": "integer",
-                    "description": "Number of custom commands registered",
-                },
-                "loaded_commands": {
-                    "type": "integer",
-                    "description": "Number of commands loaded from directory",
-                },
-                "remote_commands": {
-                    "type": "integer",
-                    "description": "Number of commands loaded from remote plugins",
-                },
-                "total_commands": {
-                    "type": "integer",
-                    "description": "Total number of commands after reload",
-                },
-                "server_restart_required": {
-                    "type": "boolean",
-                    "description": "Whether server restart is required to apply changes",
-                },
-                "message": {
-                    "type": "string",
-                    "description": "Information message about the reload operation",
-                },
-                "error_message": {
-                    "type": ["string", "null"],
-                    "description": "Error message if reload failed",
-                },
-            },
-            "required": [
-                "success",
-                "config_reloaded",
-                "builtin_commands",
-                "custom_commands",
-                "loaded_commands",
-                "remote_commands",
-                "total_commands",
-                "server_restart_required",
-            ],
-        }
 
 
 class ReloadCommand(Command):
@@ -156,12 +94,12 @@ class ReloadCommand(Command):
             ReloadResult with reload information
         """
         try:
-            logger.info("🔄 Starting configuration and commands reload...")
+            get_global_logger().info("🔄 Starting configuration and commands reload...")
 
             # Get config path from parameters
             config_path = params.get("config_path")
             if not config_path:
-                logger.warning("No config_path provided, using default configuration")
+                get_global_logger().warning("No config_path provided, using default configuration")
 
             # Perform reload using unified initialization
             reload_info = await registry.reload_system(config_path=config_path)
@@ -178,11 +116,11 @@ class ReloadCommand(Command):
                 success=True,
             )
 
-            logger.info(f"✅ Reload completed successfully: {result.to_dict()}")
+            get_global_logger().info(f"✅ Reload completed successfully: {result.to_dict()}")
             return result
 
         except Exception as e:
-            logger.error(f"❌ Reload failed: {str(e)}")
+            get_global_logger().error(f"❌ Reload failed: {str(e)}")
             return ReloadResult(
                 config_reloaded=False,
                 builtin_commands=0,
@@ -196,21 +134,3 @@ class ReloadCommand(Command):
             )
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for command parameters.
-
-        Returns:
-            JSON schema dictionary.
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "config_path": {
-                    "type": "string",
-                    "description": "Path to configuration file to reload",
-                    "default": None,
-                }
-            },
-            "additionalProperties": False,
-        }
