@@ -8,11 +8,11 @@ email: vasilyvz@gmail.com
 """
 
 import logging
-from typing import Dict, Any, Optional
 from mcp_proxy_adapter.commands.base import Command
 from mcp_proxy_adapter.commands.result import SuccessResult
 
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -35,38 +35,8 @@ class RoleTestCommandResult(SuccessResult):
         self.action = action
         self.allowed = allowed
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert to dictionary."""
-        return {
-            "success": True,
-            "data": {
-                "user_role": self.user_role,
-                "permissions": self.permissions,
-                "action": self.action,
-                "allowed": self.allowed,
-            },
-            "message": f"Action '{self.action}' {'allowed' if self.allowed else 'denied'} for role '{self.user_role}'",
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get JSON schema."""
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "data": {
-                    "type": "object",
-                    "properties": {
-                        "user_role": {"type": "string"},
-                        "permissions": {"type": "array", "items": {"type": "string"}},
-                        "action": {"type": "string"},
-                        "allowed": {"type": "boolean"},
-                    },
-                },
-                "message": {"type": "string"},
-            },
-        }
 
 
 class RoleTestCommand(Command):
@@ -104,24 +74,11 @@ class RoleTestCommand(Command):
         # Check if action is allowed
         allowed = self._check_permission(action, permissions)
 
-        logger.info(f"Role test: user={user_role}, action={action}, allowed={allowed}")
+        get_global_logger().info(f"Role test: user={user_role}, action={action}, allowed={allowed}")
 
         return RoleTestCommandResult(user_role, permissions, action, allowed)
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get JSON schema for command parameters."""
-        return {
-            "type": "object",
-            "properties": {
-                "action": {
-                    "type": "string",
-                    "description": "Action to test",
-                    "default": "read",
-                }
-            },
-            "additionalProperties": False,
-        }
 
     def _check_permission(self, action: str, permissions: list) -> bool:
         """
