@@ -10,7 +10,6 @@ Version: 1.0.0
 
 import json
 import logging
-from typing import Dict, List, Optional, Any
 from pathlib import Path
 
 from .base import Command
@@ -18,6 +17,7 @@ from .result import CommandResult, SuccessResult, ErrorResult
 from ..core.role_utils import RoleUtils
 from ..core.errors import ValidationError, NotFoundError, InternalError
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -39,57 +39,8 @@ class RolesListResult(SuccessResult):
         self.roles = roles
         self.total_count = total_count
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "success": self.success,
-            "roles": self.roles,
-            "total_count": self.total_count,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "roles": {
-                    "type": "array",
-                    "items": {
-                        "type": "object",
-                        "properties": {
-                            "name": {"type": "string"},
-                            "description": {"type": "string"},
-                            "allowed_servers": {
-                                "type": "array",
-                                "items": {"type": "string"},
-                            },
-                            "allowed_clients": {
-                                "type": "array",
-                                "items": {"type": "string"},
-                            },
-                            "permissions": {
-                                "type": "array",
-                                "items": {"type": "string"},
-                            },
-                            "priority": {"type": "integer"},
-                        },
-                    },
-                },
-                "total_count": {"type": "integer"},
-            },
-        }
 
 
 class RolesCreateResult(SuccessResult):
@@ -110,35 +61,8 @@ class RolesCreateResult(SuccessResult):
         self.role_name = role_name
         self.role_config = role_config
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "success": self.success,
-            "role_name": self.role_name,
-            "role_config": self.role_config,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "role_name": {"type": "string"},
-                "role_config": {"type": "object"},
-            },
-        }
 
 
 class RolesUpdateResult(SuccessResult):
@@ -159,35 +83,8 @@ class RolesUpdateResult(SuccessResult):
         self.role_name = role_name
         self.role_config = role_config
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "success": self.success,
-            "role_name": self.role_name,
-            "role_config": self.role_config,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "role_name": {"type": "string"},
-                "role_config": {"type": "object"},
-            },
-        }
 
 
 class RolesDeleteResult(SuccessResult):
@@ -206,30 +103,8 @@ class RolesDeleteResult(SuccessResult):
         self.success = True
         self.role_name = role_name
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {"success": self.success, "role_name": self.role_name}
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "role_name": {"type": "string"},
-            },
-        }
 
 
 class RolesValidateResult(SuccessResult):
@@ -252,37 +127,8 @@ class RolesValidateResult(SuccessResult):
         self.is_valid = is_valid
         self.validation_errors = validation_errors
 
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "success": self.success,
-            "role_name": self.role_name,
-            "is_valid": self.is_valid,
-            "validation_errors": self.validation_errors,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for result.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "success": {"type": "boolean"},
-                "role_name": {"type": "string"},
-                "is_valid": {"type": "boolean"},
-                "validation_errors": {"type": "array", "items": {"type": "string"}},
-            },
-        }
 
 
 class RolesManagementCommand(Command):
@@ -319,7 +165,7 @@ class RolesManagementCommand(Command):
         try:
             config_path = Path(self.roles_config_path)
             if not config_path.exists():
-                logger.warning(f"Roles config file not found: {self.roles_config_path}")
+                get_global_logger().warning(f"Roles config file not found: {self.roles_config_path}")
                 return {"roles": {}, "server_roles": {}, "role_hierarchy": {}}
 
             with open(config_path, "r", encoding="utf-8") as f:
@@ -328,7 +174,7 @@ class RolesManagementCommand(Command):
             return config
 
         except Exception as e:
-            logger.error(f"Failed to load roles configuration: {e}")
+            get_global_logger().error(f"Failed to load roles configuration: {e}")
             return {"roles": {}, "server_roles": {}, "role_hierarchy": {}}
 
     def _save_roles_config(self) -> None:
@@ -342,10 +188,10 @@ class RolesManagementCommand(Command):
             with open(config_path, "w", encoding="utf-8") as f:
                 json.dump(self.roles_config, f, indent=2, ensure_ascii=False)
 
-            logger.info(f"Roles configuration saved to {self.roles_config_path}")
+            get_global_logger().info(f"Roles configuration saved to {self.roles_config_path}")
 
         except Exception as e:
-            logger.error(f"Failed to save roles configuration: {e}")
+            get_global_logger().error(f"Failed to save roles configuration: {e}")
             raise InternalError(f"Failed to save roles configuration: {e}")
 
     async def execute(self, **kwargs) -> CommandResult:
@@ -378,7 +224,7 @@ class RolesManagementCommand(Command):
                 )
 
         except Exception as e:
-            logger.error(f"Roles management command failed: {e}")
+            get_global_logger().error(f"Roles management command failed: {e}")
             return ErrorResult(str(e))
 
     async def roles_list(self, **kwargs) -> RolesListResult:
@@ -473,7 +319,7 @@ class RolesManagementCommand(Command):
         # Save configuration
         self._save_roles_config()
 
-        logger.info(f"Role {role_name} created successfully")
+        get_global_logger().info(f"Role {role_name} created successfully")
         return RolesCreateResult(role_name, role_config)
 
     async def roles_update(self, **kwargs) -> RolesUpdateResult:
@@ -522,7 +368,7 @@ class RolesManagementCommand(Command):
         # Save configuration
         self._save_roles_config()
 
-        logger.info(f"Role {role_name} updated successfully")
+        get_global_logger().info(f"Role {role_name} updated successfully")
         return RolesUpdateResult(role_name, updated_config)
 
     async def roles_delete(self, **kwargs) -> RolesDeleteResult:
@@ -563,7 +409,7 @@ class RolesManagementCommand(Command):
         # Save configuration
         self._save_roles_config()
 
-        logger.info(f"Role {role_name} deleted successfully")
+        get_global_logger().info(f"Role {role_name} deleted successfully")
         return RolesDeleteResult(role_name)
 
     async def roles_validate(self, **kwargs) -> RolesValidateResult:
@@ -654,47 +500,3 @@ class RolesManagementCommand(Command):
         return errors
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get JSON schema for command parameters.
-
-        Returns:
-            JSON schema
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "action": {
-                    "type": "string",
-                    "enum": ["list", "create", "update", "delete", "validate"],
-                    "description": "Action to perform",
-                },
-                "role_name": {"type": "string", "description": "Name of the role"},
-                "description": {"type": "string", "description": "Role description"},
-                "allowed_servers": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "List of allowed servers",
-                },
-                "allowed_clients": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "List of allowed clients",
-                },
-                "permissions": {
-                    "type": "array",
-                    "items": {"type": "string"},
-                    "description": "List of permissions",
-                },
-                "priority": {"type": "integer", "description": "Role priority"},
-                "role_config": {
-                    "type": "object",
-                    "description": "Complete role configuration",
-                },
-                "filter": {"type": "string", "description": "Filter for list action"},
-                "limit": {"type": "integer", "description": "Limit for list action"},
-                "offset": {"type": "integer", "description": "Offset for list action"},
-            },
-            "required": ["action"],
-            "additionalProperties": False,
-        }
