@@ -9,13 +9,10 @@ email: vasilyvz@gmail.com
 """
 
 import logging
-from typing import Dict, Any, List, Optional
-from pathlib import Path
 
 from .base import Command
-from .result import CommandResult, SuccessResult, ErrorResult
-from mcp_proxy_adapter.core.security_integration import create_security_integration
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -43,34 +40,8 @@ class SecurityResult(CommandResult):
         self.data = data or {}
         self.error = error
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert to dictionary."""
-        return {
-            "operation": self.operation,
-            "success": self.success,
-            "data": self.data,
-            "error": self.error,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get result schema."""
-        return {
-            "type": "object",
-            "properties": {
-                "operation": {
-                    "type": "string",
-                    "description": "Security operation performed",
-                },
-                "success": {
-                    "type": "boolean",
-                    "description": "Whether operation was successful",
-                },
-                "data": {"type": "object", "description": "Operation data"},
-                "error": {"type": "string", "description": "Error message if any"},
-            },
-            "required": ["operation", "success"],
-        }
 
 
 class SecurityCommand(Command):
@@ -101,7 +72,7 @@ class SecurityCommand(Command):
         self.security_integration = create_security_integration(config)
 
         if not self.security_integration:
-            logger.warning(
+            get_global_logger().warning(
                 "Security framework not available, security command will fail"
             )
 
@@ -151,7 +122,7 @@ class SecurityCommand(Command):
                 )
 
         except Exception as e:
-            logger.error(f"Security command error: {e}")
+            get_global_logger().error(f"Security command error: {e}")
             return SecurityResult(
                 operation=action,
                 success=False,
