@@ -11,11 +11,11 @@ import logging
 import ssl
 from typing import Dict, Any, Optional
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 # Import mcp_security_framework
 try:
     from mcp_security_framework.core.ssl_manager import SSLManager
     from mcp_security_framework.schemas.config import SSLConfig
-    from mcp_security_framework.utils.cert_utils import validate_certificate_chain
 
     SECURITY_FRAMEWORK_AVAILABLE = True
 except ImportError:
@@ -84,7 +84,7 @@ class SSLSetupCommand(Command):
                 )
 
         except Exception as e:
-            logger.error(f"SSL setup command failed: {e}")
+            get_global_logger().error(f"SSL setup command failed: {e}")
             return ErrorResult(message=f"SSL setup command failed: {str(e)}")
 
     async def _get_ssl_config(self) -> SuccessResult | ErrorResult:
@@ -99,7 +99,7 @@ class SSLSetupCommand(Command):
             return SuccessResult(data={"ssl_config": ssl_config})
 
         except Exception as e:
-            logger.error(f"Failed to get SSL config: {e}")
+            get_global_logger().error(f"Failed to get SSL config: {e}")
             return ErrorResult(message=f"Failed to get SSL config: {str(e)}")
 
     async def _set_ssl_config(
@@ -127,7 +127,7 @@ class SSLSetupCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Failed to set SSL config: {e}")
+            get_global_logger().error(f"Failed to set SSL config: {e}")
             return ErrorResult(message=f"Failed to set SSL config: {str(e)}")
 
     async def _update_ssl_config(
@@ -163,7 +163,7 @@ class SSLSetupCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Failed to update SSL config: {e}")
+            get_global_logger().error(f"Failed to update SSL config: {e}")
             return ErrorResult(message=f"Failed to update SSL config: {str(e)}")
 
     async def _reset_ssl_config(self) -> SuccessResult | ErrorResult:
@@ -190,7 +190,7 @@ class SSLSetupCommand(Command):
             )
 
         except Exception as e:
-            logger.error(f"Failed to reset SSL config: {e}")
+            get_global_logger().error(f"Failed to reset SSL config: {e}")
             return ErrorResult(message=f"Failed to reset SSL config: {str(e)}")
 
     async def _test_ssl_config(
@@ -218,7 +218,7 @@ class SSLSetupCommand(Command):
                 return await self._test_ssl_config_fallback(cert_file, key_file)
 
         except Exception as e:
-            logger.error(f"Failed to test SSL config: {e}")
+            get_global_logger().error(f"Failed to test SSL config: {e}")
             return ErrorResult(message=f"Failed to test SSL config: {str(e)}")
 
     async def _test_ssl_config_with_framework(
@@ -302,46 +302,5 @@ class SSLSetupCommand(Command):
                 },
             )
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert command to dictionary."""
-        return {
-            "name": self.name,
-            "description": self.description,
-            "version": self.version,
-            "framework_available": SECURITY_FRAMEWORK_AVAILABLE,
-        }
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """Get command schema."""
-        return {
-            "type": "object",
-            "properties": {
-                "action": {
-                    "type": "string",
-                    "enum": ["get", "set", "update", "reset", "test"],
-                    "description": "Action to perform",
-                },
-                "config_data": {
-                    "type": "object",
-                    "description": "SSL configuration data",
-                    "properties": {
-                        "enabled": {"type": "boolean"},
-                        "cert_file": {"type": "string"},
-                        "key_file": {"type": "string"},
-                        "ca_file": {"type": "string"},
-                        "verify_mode": {"type": "string"},
-                        "cipher_suites": {"type": "array", "items": {"type": "string"}},
-                    },
-                },
-                "cert_file": {
-                    "type": "string",
-                    "description": "Certificate file path for testing",
-                },
-                "key_file": {
-                    "type": "string",
-                    "description": "Private key file path for testing",
-                },
-            },
-            "required": ["action"],
-        }
