@@ -4,11 +4,9 @@ Transport Management Command
 This command provides transport management functionality for the MCP Proxy Adapter.
 """
 
-from typing import Dict, Any, ClassVar
 from mcp_proxy_adapter.commands.base import Command
-from mcp_proxy_adapter.commands.result import SuccessResult, ErrorResult
 from mcp_proxy_adapter.core.transport_manager import transport_manager
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class TransportManagementResult(SuccessResult):
@@ -40,24 +38,6 @@ class TransportManagementCommand(Command):
     descr = "Manage and query transport configurations (HTTP, HTTPS, MTLS)"
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Get command schema.
-
-        Returns:
-            Command schema dictionary
-        """
-        return {
-            "type": "object",
-            "properties": {
-                "action": {
-                    "type": "string",
-                    "enum": ["get_info", "validate", "reload"],
-                    "description": "Action to perform",
-                }
-            },
-            "required": ["action"],
-        }
 
     async def execute(self, **params) -> TransportManagementResult:
         """
@@ -85,7 +65,7 @@ class TransportManagementCommand(Command):
                 )
 
         except Exception as e:
-            logger.error(f"Transport management command error: {e}")
+            get_global_logger().error(f"Transport management command error: {e}")
             return TransportManagementResult(
                 transport_info={"error": str(e)},
                 message=f"Transport management failed: {e}",
