@@ -14,13 +14,12 @@ from typing import Optional, Dict, Any
 
 from fastapi import FastAPI
 from mcp_proxy_adapter.api.app import create_app
-from mcp_proxy_adapter.core.logging import setup_logging, get_logger
+from mcp_proxy_adapter.core.logging import setup_logging, get_global_logger
 from mcp_proxy_adapter.config import config
-from mcp_proxy_adapter.commands.builtin_commands import (
-    register_builtin_commands,
-)
 
-logger = get_logger("app_factory")
+# Built-in command registration is temporarily disabled in this startup path
+
+logger = get_global_logger()
 
 
 async def create_and_run_server(
@@ -73,30 +72,31 @@ async def create_and_run_server(
             sys.exit(1)
 
         try:
-            config.load_from_file(str(config_file))
-            app_config = config.get_all()
+            from mcp_proxy_adapter.config import Config
+
+            config_instance = Config(config_path=str(config_file))
+            app_config = config_instance.config_data
             print(f"✅ Configuration loaded from: {config_path}")
 
             # Validate UUID configuration (mandatory)
             from mcp_proxy_adapter.core.config_validator import ConfigValidator
 
-            validator = ConfigValidator(app_config)
-            if not validator.validate_all():
+            validator = ConfigValidator()
+            validator.config_data = app_config
+            validation_results = validator.validate_config()
+            errors = [r for r in validation_results if r.level == "error"]
+            if errors:
                 print("❌ Configuration validation failed:")
-                for error in validator.get_errors():
+                for error in errors:
                     print(f"   - {error}")
                 sys.exit(1)
             print("✅ Configuration validation passed")
 
             # Debug: Check what config.get_all() actually returns
-            print(
-                f"🔍 Debug: config.get_all() keys: {list(app_config.keys())}"
-            )
+            print(f"🔍 Debug: config.get_all() keys: {list(app_config.keys())}")
             if "security" in app_config:
                 security_ssl = app_config["security"].get("ssl", {})
-                print(
-                    f"🔍 Debug: config.get_all() security.ssl: {security_ssl}"
-                )
+                print(f"🔍 Debug: config.get_all() security.ssl: {security_ssl}")
 
             # Debug: Check if root ssl section exists after loading
             if "ssl" in app_config:
@@ -110,11 +110,11 @@ async def create_and_run_server(
                     f"🔍 Debug: Root SSL section after loading: key_file={app_config['ssl'].get('key_file')}"
                 )
             else:
-                print(f"🔍 Debug: No root SSL section after loading")
+                print("🔍 Debug: No root SSL section after loading")
 
             # Debug: Check app_config immediately after get_all()
-            if app_config and "security" in app_config:
-                ssl_config = app_config["security"].get("ssl", {})
+            if app_config and "ssl" in app_config:
+                ssl_config = app_config["ssl"]
                 print(
                     f"🔍 Debug: app_config after get_all(): SSL enabled={ssl_config.get('enabled', False)}"
                 )
@@ -125,46 +125,66 @@ async def create_and_run_server(
                     f"🔍 Debug: app_config after get_all(): SSL key_file={ssl_config.get('key_file')}"
                 )
 
-            # Debug: Check SSL configuration after loading
-            if app_config and "security" in app_config:
-                ssl_config = app_config["security"].get("ssl", {})
-                print(
-                    f"🔍 Debug: SSL config after loading: enabled={ssl_config.get('enabled', False)}"
-                )
-                print(
-                    f"🔍 Debug: SSL config after loading: cert_file={ssl_config.get('cert_file')}"
-                )
-                print(
-                    f"🔍 Debug: SSL config after loading: key_file={ssl_config.get('key_file')}"
-                )
-
-                # Debug: Check if SSL config is correct
-                if ssl_config.get("enabled", False):
-                    print(f"🔍 Debug: SSL config is enabled and correct")
-                else:
-                    print(f"🔍 Debug: SSL config is disabled or incorrect")
-                    # Try to get SSL config from root level
-                    root_ssl = app_config.get("ssl", {})
-                    print(
-                        f"🔍 Debug: Root SSL config: enabled={root_ssl.get('enabled', False)}"
+            # CRITICAL: Validate SSL configuration - NO FALLBACKS!
+            if app_config and "ssl" in app_config:
+                ssl_config = app_config["ssl"]
+                ssl_enabled = ssl_config.get("enabled", False)
+                protocol = app_config.get("server", {}).get("protocol", "http")
+                
+                print(f"🔍 Debug: SSL enabled={ssl_enabled}, protocol={protocol}")
+                
+                # CRITICAL CHECK: If SSL is enabled, protocol MUST be https or mtls
+                if ssl_enabled and protocol not in ["https", "mtls"]:
+                    raise ValueError(
+                        f"CRITICAL CONFIG ERROR: SSL is enabled but protocol is '{protocol}'. "
+                        f"Protocol MUST be 'https' or 'mtls' when SSL is enabled. "
+                        f"Fix your configuration file."
                     )
-                    print(
-                        f"🔍 Debug: Root SSL config: cert_file={root_ssl.get('cert_file')}"
+                
+                # CRITICAL CHECK: If protocol is https/mtls, SSL MUST be enabled
+                if protocol in ["https", "mtls"] and not ssl_enabled:
+                    raise ValueError(
+                        f"CRITICAL CONFIG ERROR: Protocol is '{protocol}' but SSL is disabled. "
+                        f"SSL MUST be enabled when protocol is 'https' or 'mtls'. "
+                        f"Fix your configuration file."
                     )
+                
+                # CRITICAL CHECK: If SSL is enabled, cert and key files MUST exist
+                if ssl_enabled:
+                    cert_file = ssl_config.get("cert_file")
+                    key_file = ssl_config.get("key_file")
+                    
+                    if not cert_file or not key_file:
+                        raise ValueError(
+                            f"CRITICAL CONFIG ERROR: SSL is enabled but cert_file or key_file is missing. "
+                            f"cert_file={cert_file}, key_file={key_file}. "
+                            f"Fix your configuration file."
+                        )
+                    
+                    if not Path(cert_file).exists():
+                        raise ValueError(
+                            f"CRITICAL CONFIG ERROR: SSL certificate file does not exist: {cert_file}. "
+                            f"Fix your configuration file or create the certificate."
+                        )
+                    
+                    if not Path(key_file).exists():
+                        raise ValueError(
+                            f"CRITICAL CONFIG ERROR: SSL key file does not exist: {key_file}. "
+                            f"Fix your configuration file or create the key."
+                        )
+                    
                     print(
-                        f"🔍 Debug: Root SSL config: key_file={root_ssl.get('key_file')}"
+                        f"✅ SSL configuration validated: cert={cert_file}, key={key_file}"
                     )
 
             # Validate security framework configuration only if enabled
             security_config = app_config.get("security", {})
             if security_config.get("enabled", False):
-                framework = security_config.get(
-                    "framework", "mcp_security_framework"
-                )
+                framework = security_config.get("framework", "mcp_security_framework")
                 print(f"🔒 Security framework: {framework}")
 
                 # Debug: Check SSL config before validation
-                ssl_config = security_config.get("ssl", {})
+                ssl_config = app_config.get("ssl", {})
                 print(
                     f"🔍 Debug: SSL config before validation: enabled={ssl_config.get('enabled', False)}"
                 )
@@ -178,7 +198,7 @@ async def create_and_run_server(
                 validation_result = adapter.validate_configuration(app_config)
 
                 # Debug: Check SSL config after validation
-                ssl_config = app_config.get("security", {}).get("ssl", {})
+                ssl_config = app_config.get("ssl", {})
                 print(
                     f"🔍 Debug: SSL config after validation: enabled={ssl_config.get('enabled', False)}"
                 )
@@ -203,16 +223,14 @@ async def create_and_run_server(
             sys.exit(1)
     else:
         print("⚠️  No configuration file provided, using defaults")
-        app_config = config.get_all()
+        app_config = config.config_data
 
     # 2. Setup logging
     try:
         if log_config_path:
             log_config_file = Path(log_config_path)
             if not log_config_file.exists():
-                print(
-                    f"❌ Log configuration file not found: {log_config_path}"
-                )
+                print(f"❌ Log configuration file not found: {log_config_path}")
                 sys.exit(1)
             setup_logging(log_config_path=str(log_config_file))
             print(f"✅ Logging configured from: {log_config_path}")
@@ -223,13 +241,8 @@ async def create_and_run_server(
         print(f"❌ Failed to setup logging: {e}")
         sys.exit(1)
 
-    # 3. Register built-in commands
-    try:
-        builtin_count = register_builtin_commands()
-        print(f"✅ Registered {builtin_count} built-in commands")
-    except Exception as e:
-        print(f"❌ Failed to register built-in commands: {e}")
-        sys.exit(1)
+    # 3. Register built-in commands (disabled)
+    print("⚠️  Built-in command registration disabled for simplified startup")
 
     # 4. Create FastAPI application with configuration
     try:
@@ -260,9 +273,7 @@ async def create_and_run_server(
 
     # 5. Create server configuration
     # Get port from config if available, otherwise use default
-    server_port = (
-        app_config.get("server", {}).get("port", 8000) if app_config else 8000
-    )
+    server_port = app_config.get("server", {}).get("port", 8000) if app_config else 8000
     print(f"🔌 Port: {server_port}")
 
     server_config = {
@@ -277,23 +288,23 @@ async def create_and_run_server(
         f"🔍 Debug: app_config keys: {list(app_config.keys()) if app_config else 'None'}"
     )
 
-    # Check for SSL config in root section first (higher priority)
+    # Check for SSL config in root ssl section first (new format)
     if app_config and "ssl" in app_config:
-        print(f"🔍 Debug: SSL config found in root: {app_config['ssl']}")
-        print(
-            f"🔍 Debug: SSL enabled: {app_config['ssl'].get('enabled', False)}"
-        )
-        if app_config["ssl"].get("enabled", False):
-            ssl_config = app_config["ssl"]
+        ssl_config = app_config["ssl"]
+        print(f"🔍 Debug: SSL config found in root: {ssl_config}")
+        print(f"🔍 Debug: SSL enabled: {ssl_config.get('enabled', False)}")
+        if ssl_config.get("enabled", False):
             # Add SSL config directly to server_config for Hypercorn
             server_config["certfile"] = ssl_config.get("cert_file")
             server_config["keyfile"] = ssl_config.get("key_file")
             server_config["ca_certs"] = ssl_config.get(
                 "ca_cert_file", ssl_config.get("ca_cert")
             )
-            # Set verify_client based on verify_client setting
-            verify_client = ssl_config.get("verify_client", False)
-            server_config["verify_client"] = verify_client
+            # Set verify_mode based on verify_client setting
+            if ssl_config.get("verify_client", False):
+                server_config["verify_mode"] = "CERT_REQUIRED"
+            else:
+                server_config["verify_mode"] = ssl_config.get("verify_mode")
             print(f"🔒 SSL enabled: {ssl_config.get('cert_file', 'N/A')}")
             print(
                 f"🔒 SSL enabled: cert={ssl_config.get('cert_file')}, key={ssl_config.get('key_file')}"
@@ -305,13 +316,9 @@ async def create_and_run_server(
     # Check for SSL config in security section (fallback)
     if app_config and "security" in app_config:
         security_config = app_config["security"]
-        print(
-            f"🔍 Debug: security_config keys: {list(security_config.keys())}"
-        )
+        print(f"🔍 Debug: security_config keys: {list(security_config.keys())}")
         if "ssl" in security_config:
-            print(
-                f"🔍 Debug: SSL config found in security: {security_config['ssl']}"
-            )
+            print(f"🔍 Debug: SSL config found in security: {security_config['ssl']}")
             print(
                 f"🔍 Debug: SSL enabled: {security_config['ssl'].get('enabled', False)}"
             )
@@ -331,28 +338,6 @@ async def create_and_run_server(
                 print(
                     f"🔒 Server config SSL: certfile={server_config.get('certfile')}, keyfile={server_config.get('keyfile')}, ca_certs={server_config.get('ca_certs')}, verify_mode={server_config.get('verify_mode')}"
                 )
-        print(f"🔍 Debug: SSL config found in root: {app_config['ssl']}")
-        print(
-            f"🔍 Debug: SSL enabled: {app_config['ssl'].get('enabled', False)}"
-        )
-        if app_config["ssl"].get("enabled", False):
-            ssl_config = app_config["ssl"]
-            # Add SSL config directly to server_config for Hypercorn
-            server_config["certfile"] = ssl_config.get("cert_file")
-            server_config["keyfile"] = ssl_config.get("key_file")
-            server_config["ca_certs"] = ssl_config.get(
-                "ca_cert_file", ssl_config.get("ca_cert")
-            )
-            # Set verify_client based on verify_client setting
-            verify_client = ssl_config.get("verify_client", False)
-            server_config["verify_client"] = verify_client
-            print(f"🔒 SSL enabled: {ssl_config.get('cert_file', 'N/A')}")
-            print(
-                f"🔒 SSL enabled: cert={ssl_config.get('cert_file')}, key={ssl_config.get('key_file')}"
-            )
-            print(
-                f"🔒 Server config SSL: certfile={server_config.get('certfile')}, keyfile={server_config.get('keyfile')}, ca_certs={server_config.get('ca_certs')}, verify_mode={server_config.get('verify_mode')}"
-            )
 
     # 6. Start mTLS server if needed
     mtls_server = None
@@ -362,18 +347,21 @@ async def create_and_run_server(
         verify_client = ssl_config.get("verify_client", False)
 
         if verify_client:
-            print("🔐 mTLS enabled - starting separate mTLS server...")
+            print("🔐 mTLS enabled - starting internal mTLS server...")
+            print("   External port: mTLS proxy (hypercorn)")
+            print("   Internal port: mTLS server (http.server)")
             from mcp_proxy_adapter.core.mtls_server import (
                 start_mtls_server_thread,
             )
 
-            # Start mTLS server in separate thread
+            # Start internal mTLS server in separate thread
+            # This server will find available port automatically if needed
             mtls_server = start_mtls_server_thread(app_config, main_app=app)
             if mtls_server:
-                print(f"✅ mTLS server started on port {mtls_server.port}")
+                print(f"✅ Internal mTLS server started on port {mtls_server.port}")
             else:
                 print(
-                    "⚠️  Failed to start mTLS server, continuing with regular HTTPS"
+                    "⚠️  Failed to start internal mTLS server, continuing with regular HTTPS"
                 )
         else:
             print("🔓 mTLS disabled - using regular HTTPS")
@@ -387,6 +375,8 @@ async def create_and_run_server(
         print("   Use Ctrl+C to stop the server")
         print("=" * 60)
 
+        # Port availability is already checked in api/app.py before registration manager starts
+
         # Use hypercorn directly
         import hypercorn.asyncio
         import hypercorn.config
@@ -395,9 +385,7 @@ async def create_and_run_server(
 
         # Configure hypercorn
         config_hypercorn = hypercorn.config.Config()
-        config_hypercorn.bind = [
-            f"{server_config['host']}:{server_config['port']}"
-        ]
+        config_hypercorn.bind = [f"{server_config['host']}:{server_config['port']}"]
         config_hypercorn.loglevel = server_config.get("log_level", "info")
         
         # Add SSL shutdown timeout to prevent SSL shutdown timeout errors
@@ -411,29 +399,27 @@ async def create_and_run_server(
             config_hypercorn.keyfile = server_config["keyfile"]
         if "ca_certs" in server_config:
             config_hypercorn.ca_certs = server_config["ca_certs"]
-        if "verify_mode" in server_config:
+        if "verify_mode" in server_config and server_config["verify_mode"] is not None:
             import ssl
 
             # Use the verify_mode from configuration, default to CERT_NONE
-            verify_mode = getattr(
-                ssl, server_config["verify_mode"], ssl.CERT_NONE
-            )
+            verify_mode = getattr(ssl, server_config["verify_mode"], ssl.CERT_NONE)
             config_hypercorn.verify_mode = verify_mode
 
         # Determine if SSL is enabled
-        ssl_enabled = any(
-            key in server_config for key in ["certfile", "keyfile"]
-        )
+        ssl_enabled = any(key in server_config for key in ["certfile", "keyfile"])
 
         if ssl_enabled:
             if verify_client:
                 print(
-                    f"🔐 Starting HTTPS server with hypercorn (mTLS on separate port)..."
+                    f"🔐 Starting external mTLS proxy with hypercorn (internal server on port {mtls_server.port if mtls_server else 'N/A'})..."
                 )
             else:
-                print(f"🔐 Starting HTTPS server with hypercorn...")
+                print("🔐 Starting HTTPS server with hypercorn...")
         else:
-            print(f"🌐 Starting HTTP server with hypercorn...")
+            print("🌐 Starting HTTP server with hypercorn...")
+
+        # Final port check disabled in this refactor; rely on OS errors
 
         # Run the server
         # hypercorn.asyncio.serve() should be run with asyncio.run(), not awaited
@@ -442,11 +428,11 @@ async def create_and_run_server(
 
     except KeyboardInterrupt:
         print("\n🛑 Server stopped by user")
-        # Stop mTLS server if running
+        # Stop internal mTLS server if running
         if mtls_server:
-            print("🛑 Stopping mTLS server...")
+            print("🛑 Stopping internal mTLS server...")
             mtls_server.stop()
-    except Exception as e:
+    except OSError as e:
         print(f"\n❌ Failed to start server: {e}")
         # Stop mTLS server if running
         if mtls_server:
@@ -456,6 +442,16 @@ async def create_and_run_server(
 
         traceback.print_exc()
         sys.exit(1)
+    except Exception as e:
+        print(f"\n❌ Failed to start server: {e}")
+        # Stop internal mTLS server if running
+        if mtls_server:
+            print("🛑 Stopping internal mTLS server...")
+            mtls_server.stop()
+        import traceback
+
+        traceback.print_exc()
+        sys.exit(1)
 
 
 def validate_config_file(config_path: str) -> bool:
@@ -475,7 +471,9 @@ def validate_config_file(config_path: str) -> bool:
             return False
 
         # Try to load configuration to validate JSON format
-        config.load_from_file(str(config_file))
+        from mcp_proxy_adapter.config import Config
+
+        Config(config_path=str(config_file))
         return True
 
     except Exception as e:
