@@ -11,11 +11,15 @@ with full configuration validation and error handling.
 import socket
 import sys
 from pathlib import Path
-from typing import Dict, Any, List, Optional
+from typing import Any, Dict, List
 
 from fastapi import FastAPI
 
 from mcp_proxy_adapter.core.logging import get_logger
+from mcp_proxy_adapter.core.signal_handler import (
+    setup_signal_handling,
+    is_shutdown_requested,
+)
 
 logger = get_logger("app_runner")
 
@@ -86,29 +90,30 @@ class ApplicationRunner:
             self.errors.append(f"Invalid server port: {port}")
 
     def _validate_ssl_config(self) -> None:
-        """Validate SSL configuration."""
-        ssl_config = self.config.get("ssl", {})
+        """Validate SSL configuration based on protocol."""
+        server_config = self.config.get("server", {})
+        protocol = server_config.get("protocol", "http")
 
-        if ssl_config.get("enabled", False):
+        # SSL is automatically enabled for https and mtls protocols
+        if protocol in ("https", "mtls"):
+        ssl_config = self.config.get("ssl", {})
             cert_file = ssl_config.get("cert_file")
             key_file = ssl_config.get("key_file")
 
-            if not cert_file:
-                self.errors.append("SSL enabled but certificate file not specified")
-            elif not Path(cert_file).exists():
+            # Only validate if certificates are specified
+            if cert_file and key_file:
+                if not Path(cert_file).exists():
                 self.errors.append(f"Certificate file not found: {cert_file}")
 
-            if not key_file:
-                self.errors.append("SSL enabled but private key file not specified")
-            elif not Path(key_file).exists():
+                if not Path(key_file).exists():
                 self.errors.append(f"Private key file not found: {key_file}")
 
             # Validate mTLS configuration
-            if ssl_config.get("verify_client", False):
+            if protocol == "mtls" or ssl_config.get("verify_client", False):
                 ca_cert = ssl_config.get("ca_cert")
                 if not ca_cert:
                     self.errors.append(
-                        "Client verification enabled but CA certificate not specified"
+                        f"{protocol.upper()} requires CA certificate to be specified"
                     )
                 elif not Path(ca_cert).exists():
                     self.errors.append(f"CA certificate file not found: {ca_cert}")
@@ -143,11 +148,13 @@ class ApplicationRunner:
 
                 # Validate certificate configuration
                 if "certificate" in methods:
-                    ssl_config = self.config.get("ssl", {})
-                    if not ssl_config.get("enabled", False):
+                    server_config = self.config.get("server", {})
+                    protocol = server_config.get("protocol", "http")
+                    if protocol not in ("https", "mtls"):
                         self.errors.append(
-                            "Certificate authentication requires SSL to be enabled"
+                            "Certificate authentication requires https or mtls protocol"
                         )
+                    ssl_config = self.config.get("ssl", {})
                     if not ssl_config.get("verify_client", False):
                         self.errors.append(
                             "Certificate authentication requires client verification to be enabled"
@@ -155,13 +162,17 @@ class ApplicationRunner:
 
     def _validate_file_paths(self) -> None:
         """Validate all file paths in configuration."""
-        # Check SSL certificate files
+        # Check SSL certificate files based on protocol
+        server_config = self.config.get("server", {})
+        protocol = server_config.get("protocol", "http")
+
+        if protocol in ("https", "mtls"):
         ssl_config = self.config.get("ssl", {})
-        if ssl_config.get("enabled", False):
             cert_file = ssl_config.get("cert_file")
             key_file = ssl_config.get("key_file")
             ca_cert = ssl_config.get("ca_cert")
 
+            # Only validate if certificates are specified
             if cert_file and not Path(cert_file).is_file():
                 self.errors.append(
                     f"Certificate file is not a regular file: {cert_file}"
@@ -199,24 +210,27 @@ class ApplicationRunner:
 
     def _validate_compatibility(self) -> None:
         """Validate configuration compatibility."""
-        ssl_config = self.config.get("ssl", {})
+        server_config = self.config.get("server", {})
+        protocol = server_config.get("protocol", "http")
         security_config = self.config.get("security", {})
         protocols_config = self.config.get("protocols", {})
 
-        # Check SSL and protocol compatibility
-        if ssl_config.get("enabled", False):
+        # Check protocol compatibility
+        if protocol in ("https", "mtls"):
             allowed_protocols = protocols_config.get("allowed_protocols", [])
-            if "http" in allowed_protocols and "https" not in allowed_protocols:
-                self.errors.append("SSL enabled but HTTPS not in allowed protocols")
+            if allowed_protocols and protocol not in allowed_protocols:
+                self.errors.append(
+                    f"Protocol {protocol} is not in allowed protocols: {allowed_protocols}"
+                )
 
-        # Check security and SSL compatibility
+        # Check security and protocol compatibility
         if security_config.get("enabled", False):
             auth_config = security_config.get("auth", {})
             if auth_config.get("enabled", False):
                 methods = auth_config.get("methods", [])
-                if "certificate" in methods and not ssl_config.get("enabled", False):
+                if "certificate" in methods and protocol not in ("https", "mtls"):
                     self.errors.append(
-                        "Certificate authentication requires SSL to be enabled"
+                        "Certificate authentication requires https or mtls protocol"
                     )
 
     def setup_hooks(self) -> None:
@@ -226,16 +240,13 @@ class ApplicationRunner:
 
         # Add startup event
         @self.app.on_event("startup")
-        async def startup_event():
-            logger.info("Application starting up")
-            logger.info(
-                f"Configuration validation passed with {len(self.errors)} errors"
-            )
+        def startup():
+            pass
 
         # Add shutdown event
         @self.app.on_event("shutdown")
-        async def shutdown_event():
-            logger.info("Application shutting down")
+        def shutdown():
+            pass
 
     def run(self) -> None:
         """
@@ -250,6 +261,14 @@ class ApplicationRunner:
                 print(f"  - {error}", file=sys.stderr)
             sys.exit(1)
 
+        # Setup signal handling for graceful shutdown
+        def shutdown_callback():
+            """Callback for graceful shutdown."""
+            logger.info("Graceful shutdown requested")
+        
+        setup_signal_handling(shutdown_callback)
+        print("🔧 Signal handling configured for graceful shutdown")
+
         # Setup hooks
         self.setup_hooks()
 
@@ -261,29 +280,39 @@ class ApplicationRunner:
         # Prepare server configuration for hypercorn
         server_kwargs = {"host": host, "port": port, "log_level": "info"}
 
-        # Add SSL configuration if enabled
+        # Add SSL configuration based on protocol
+        protocol = server_config.get("protocol", "http")
+        if protocol in ("https", "mtls"):
         ssl_config = self.config.get("ssl", {})
-        if ssl_config.get("enabled", False):
-            server_kwargs["certfile"] = ssl_config.get("cert_file")
-            server_kwargs["keyfile"] = ssl_config.get("key_file")
+            cert_file = ssl_config.get("cert_file")
+            key_file = ssl_config.get("key_file")
 
-            # Add mTLS configuration if enabled
-            if ssl_config.get("verify_client", False):
-                server_kwargs["ca_certs"] = ssl_config.get("ca_cert")
+            # Only add SSL config if certificates are specified
+            if cert_file and key_file:
+                server_kwargs["certfile"] = cert_file
+                server_kwargs["keyfile"] = key_file
+
+            # Add mTLS configuration
+            if protocol == "mtls" or ssl_config.get("verify_client", False):
+                ca_cert = ssl_config.get("ca_cert")
+                if ca_cert:
+                    server_kwargs["ca_certs"] = ca_cert
 
         try:
             import hypercorn.asyncio
             import asyncio
 
             print(f"🚀 Starting server on {host}:{port}")
-            print("   Use Ctrl+C to stop the server")
+            print("🛑 Use Ctrl+C or send SIGTERM for graceful shutdown")
             print("=" * 60)
 
             # Run with hypercorn
             asyncio.run(hypercorn.asyncio.serve(self.app, **server_kwargs))
 
         except KeyboardInterrupt:
-            print("\n🛑 Server stopped by user")
+            print("\n🛑 Server stopped by user (Ctrl+C)")
+            if is_shutdown_requested():
+                print("✅ Graceful shutdown completed")
         except Exception as e:
             print(f"\n❌ Failed to start server: {e}", file=sys.stderr)
             sys.exit(1)
