@@ -12,12 +12,10 @@ import json
 import logging
 import os
 from datetime import datetime
-from typing import Dict, List, Optional, Any, Union
 from pathlib import Path
+from typing import Optional, Dict, Any, List
 
 from cryptography import x509
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.asymmetric import rsa, padding
 
 
 # Standard JSON-RPC error codes
@@ -71,36 +69,7 @@ class AuthValidationResult:
         self.error_message = error_message
         self.roles = roles or []
 
-    def to_json_rpc_error(self) -> Dict[str, Any]:
-        """
-        Convert to JSON-RPC error format.
 
-        Returns:
-            JSON-RPC error dictionary
-        """
-        if self.is_valid:
-            return {}
-
-        return {
-            "code": self.error_code or -32603,
-            "message": self.error_message
-            or JSON_RPC_ERRORS.get(self.error_code, "Unknown error"),
-            "data": {"validation_type": "authentication", "roles": self.roles},
-        }
-
-    def to_dict(self) -> Dict[str, Any]:
-        """
-        Convert to dictionary format.
-
-        Returns:
-            Dictionary representation
-        """
-        return {
-            "is_valid": self.is_valid,
-            "error_code": self.error_code,
-            "error_message": self.error_message,
-            "roles": self.roles,
-        }
 
 
 class AuthValidator:
@@ -127,67 +96,6 @@ class AuthValidator:
         # Custom OID for roles
         self.role_oid = "1.3.6.1.4.1.99999.1"
 
-    def validate_auth(
-        self, auth_data: Dict[str, Any], auth_type: str = "auto"
-    ) -> AuthValidationResult:
-        """
-        Universal authentication validation.
-
-        Logic:
-        1. Check SSL configuration
-        2. If SSL disabled - return success
-        3. Determine validation type (auto/ssl/mtls/token)
-        4. Check for required data
-        5. Perform validation
-        6. Return result with JSON-RPC error code
-
-        Args:
-            auth_data: Authentication data dictionary
-            auth_type: Type of authentication to validate
-
-        Returns:
-            Authentication validation result
-        """
-        try:
-            # Determine validation type
-            if auth_type == "auto":
-                auth_type = self._get_validation_mode()
-
-            # Check for unsupported types first
-            if auth_type not in ["certificate", "token", "mtls", "ssl"]:
-                return AuthValidationResult(
-                    is_valid=False,
-                    error_code=-32602,
-                    error_message=f"Unsupported authentication type: {auth_type}",
-                )
-
-            # Check if authentication is enabled for the determined type
-            if not self._check_config(auth_type):
-                return AuthValidationResult(is_valid=True, roles=[])
-
-            # Validate based on type
-            if auth_type == "certificate":
-                return self.validate_certificate(
-                    auth_data.get("cert_path"), auth_data.get("cert_type", "server")
-                )
-            elif auth_type == "token":
-                return self.validate_token(
-                    auth_data.get("token"), auth_data.get("token_type", "jwt")
-                )
-            elif auth_type == "mtls":
-                return self.validate_mtls(
-                    auth_data.get("client_cert"), auth_data.get("ca_cert")
-                )
-            elif auth_type == "ssl":
-                return self.validate_ssl(auth_data.get("server_cert"))
-
-        except Exception as e:
-            self.logger.error(f"Authentication validation error: {e}")
-            return AuthValidationResult(
-                is_valid=False,
-                error_code=-32603,
-                error_message=f"Internal validation error: {str(e)}",
-            )
 
     def validate_certificate(
         self, cert_path: Optional[str], cert_type: str = "server"
@@ -256,7 +164,7 @@ class AuthValidator:
             return AuthValidationResult(is_valid=True, roles=roles)
 
         except Exception as e:
-            self.logger.error(f"Certificate validation error: {e}")
+            self.get_global_logger().error(f"Certificate validation error: {e}")
             return AuthValidationResult(
                 is_valid=False,
                 error_code=-32003,
@@ -296,7 +204,7 @@ class AuthValidator:
                 )
 
         except Exception as e:
-            self.logger.error(f"Token validation error: {e}")
+            self.get_global_logger().error(f"Token validation error: {e}")
             return AuthValidationResult(
                 is_valid=False,
                 error_code=-32004,
@@ -345,7 +253,7 @@ class AuthValidator:
             return AuthValidationResult(is_valid=True, roles=client_result.roles)
 
         except Exception as e:
-            self.logger.error(f"mTLS validation error: {e}")
+            self.get_global_logger().error(f"mTLS validation error: {e}")
             return AuthValidationResult(
                 is_valid=False,
                 error_code=-32005,
@@ -374,7 +282,7 @@ class AuthValidator:
             return self.validate_certificate(server_cert, "server")
 
         except Exception as e:
-            self.logger.error(f"SSL validation error: {e}")
+            self.get_global_logger().error(f"SSL validation error: {e}")
             return AuthValidationResult(
                 is_valid=False,
                 error_code=-32006,
@@ -444,7 +352,7 @@ class AuthValidator:
             return []
 
         except Exception as e:
-            self.logger.error(f"Failed to extract roles from certificate: {e}")
+            self.get_global_logger().error(f"Failed to extract roles from certificate: {e}")
             return []
 
     def _validate_server_certificate(self, cert: x509.Certificate) -> bool:
@@ -467,7 +375,7 @@ class AuthValidator:
             return True
 
         except Exception as e:
-            self.logger.error(f"Server certificate validation error: {e}")
+            self.get_global_logger().error(f"Server certificate validation error: {e}")
             return False
 
     def _validate_client_certificate(self, cert: x509.Certificate) -> bool:
@@ -492,7 +400,7 @@ class AuthValidator:
             return True
 
         except Exception as e:
-            self.logger.error(f"Client certificate validation error: {e}")
+            self.get_global_logger().error(f"Client certificate validation error: {e}")
             return False
 
     def _validate_jwt_token(self, token: str) -> AuthValidationResult:
@@ -596,5 +504,5 @@ class AuthValidator:
             return True
 
         except Exception as e:
-            self.logger.error(f"Certificate chain verification error: {e}")
+            self.get_global_logger().error(f"Certificate chain verification error: {e}")
             return False
