@@ -14,13 +14,12 @@ import json
 import os
 import ssl
 import time
-from typing import Dict, Any, Optional, List, Union
-from urllib.parse import urljoin
 from pathlib import Path
+from typing import Any, Dict, Optional
+from urllib.parse import urljoin
 
 import aiohttp
 import requests
-from requests.exceptions import RequestException
 
 # Import security framework components
 try:
@@ -29,17 +28,11 @@ try:
         AuthManager,
         CertificateManager,
         PermissionManager,
-    )
-    from mcp_security_framework.utils import (
         generate_api_key,
         create_jwt_token,
         validate_jwt_token,
-    )
-    from mcp_security_framework.utils import (
         extract_roles_from_cert,
         validate_certificate_chain,
-    )
-    from mcp_security_framework.utils import (
         create_ssl_context,
         validate_server_certificate,
     )
@@ -47,6 +40,14 @@ try:
     SECURITY_FRAMEWORK_AVAILABLE = True
 except ImportError:
     SECURITY_FRAMEWORK_AVAILABLE = False
+    # Define stubs for missing imports
+    generate_api_key = None
+    create_jwt_token = None
+    validate_jwt_token = None
+    extract_roles_from_cert = None
+    validate_certificate_chain = None
+    create_ssl_context = None
+    validate_server_certificate = None
 
 
 class UniversalClient:
