@@ -46,7 +46,7 @@ class ClientManager:
         self.retry_attempts = config.get("retry_attempts", 3)
         self.retry_delay = config.get("retry_delay", 1)
 
-        self.logger.info("Client manager initialized")
+        self.get_global_logger().info("Client manager initialized")
 
     async def create_client(self, client_id: str, config_file: str) -> UniversalClient:
         """
@@ -61,7 +61,7 @@ class ClientManager:
         """
         try:
             if client_id in self.clients:
-                self.logger.warning(
+                self.get_global_logger().warning(
                     f"Client {client_id} already exists, reusing existing connection"
                 )
                 return self.clients[client_id]
@@ -69,11 +69,11 @@ class ClientManager:
             client = create_client_from_config(config_file)
             self.clients[client_id] = client
 
-            self.logger.info(f"Client {client_id} created successfully")
+            self.get_global_logger().info(f"Client {client_id} created successfully")
             return client
 
         except Exception as e:
-            self.logger.error(f"Failed to create client {client_id}: {e}")
+            self.get_global_logger().error(f"Failed to create client {client_id}: {e}")
             raise
 
     async def get_client(self, client_id: str) -> Optional[UniversalClient]:
@@ -102,7 +102,7 @@ class ClientManager:
             client = self.clients[client_id]
             await client.disconnect()
             del self.clients[client_id]
-            self.logger.info(f"Client {client_id} removed")
+            self.get_global_logger().info(f"Client {client_id} removed")
             return True
         return False
 
@@ -118,13 +118,13 @@ class ClientManager:
         """
         client = await self.get_client(client_id)
         if not client:
-            self.logger.error(f"Client {client_id} not found")
+            self.get_global_logger().error(f"Client {client_id} not found")
             return False
 
         try:
             return await client.test_connection()
         except Exception as e:
-            self.logger.error(f"Connection test failed for client {client_id}: {e}")
+            self.get_global_logger().error(f"Connection test failed for client {client_id}: {e}")
             return False
 
     async def register_proxy(
@@ -146,10 +146,10 @@ class ClientManager:
 
         try:
             result = await client.register_proxy(proxy_config)
-            self.logger.info(f"Proxy registration completed for client {client_id}")
+            self.get_global_logger().info(f"Proxy registration completed for client {client_id}")
             return result
         except Exception as e:
-            self.logger.error(f"Proxy registration failed for client {client_id}: {e}")
+            self.get_global_logger().error(f"Proxy registration failed for client {client_id}: {e}")
             return {"error": str(e)}
 
     async def execute_command(
@@ -172,10 +172,10 @@ class ClientManager:
 
         try:
             result = await client.execute_command(command, params or {})
-            self.logger.info(f"Command {command} executed for client {client_id}")
+            self.get_global_logger().info(f"Command {command} executed for client {client_id}")
             return result
         except Exception as e:
-            self.logger.error(f"Command execution failed for client {client_id}: {e}")
+            self.get_global_logger().error(f"Command execution failed for client {client_id}: {e}")
             return {"error": str(e)}
 
     async def get_client_status(self, client_id: str) -> Dict[str, Any]:
@@ -210,23 +210,15 @@ class ClientManager:
 
             return status
         except Exception as e:
-            self.logger.error(f"Failed to get status for client {client_id}: {e}")
+            self.get_global_logger().error(f"Failed to get status for client {client_id}: {e}")
             return {"error": str(e)}
 
-    async def list_clients(self) -> List[str]:
-        """
-        Get list of all client identifiers.
-
-        Returns:
-            List of client identifiers
-        """
-        return list(self.clients.keys())
 
     async def cleanup(self):
         """Clean up all client connections."""
         for client_id in list(self.clients.keys()):
             await self.remove_client(client_id)
-        self.logger.info("All client connections cleaned up")
+        self.get_global_logger().info("All client connections cleaned up")
 
     async def __aenter__(self):
         """Async context manager entry."""
@@ -237,17 +229,6 @@ class ClientManager:
         await self.cleanup()
 
 
-def create_client_manager(config: Dict[str, Any]) -> ClientManager:
-    """
-    Create a ClientManager instance.
-
-    Args:
-        config: Client manager configuration
-
-    Returns:
-        ClientManager instance
-    """
-    return ClientManager(config)
 
 
 # Example usage and testing functions
