@@ -8,17 +8,15 @@ Author: Vasiliy Zdanovskiy
 email: vasilyvz@gmail.com
 """
 
-import logging
 import ssl
 from typing import Dict, Any, Optional, List, Tuple
 from pathlib import Path
 
 # Import framework utilities
 try:
-    from mcp_security_framework.utils.crypto_utils import (
+    from mcp_security_framework.utils import (
         generate_api_key,
         create_jwt_token,
-        verify_jwt_token,
     )
     from mcp_security_framework.utils.cert_utils import (
         parse_certificate,
@@ -26,20 +24,21 @@ try:
         validate_certificate_chain,
         validate_certificate_format,
     )
+    from mcp_security_framework import SSLConfig
     from mcp_security_framework.core.ssl_manager import SSLManager
-    from mcp_security_framework.schemas.config import SSLConfig, AuthConfig
     from mcp_security_framework.schemas.models import AuthResult, ValidationResult
 
     SECURITY_FRAMEWORK_AVAILABLE = True
-except ImportError:
-    SECURITY_FRAMEWORK_AVAILABLE = False
-    SSLManager = None
-    SSLConfig = None
-    AuthConfig = None
+except ImportError as e:
+    # NO FALLBACK! mcp_security_framework is REQUIRED
+    raise RuntimeError(
+        f"CRITICAL: mcp_security_framework is required but not available: {e}. "
+        "Install it with: pip install mcp_security_framework>=1.2.8"
+    ) from e
     AuthResult = None
     ValidationResult = None
 
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class ClientSecurityManager:
@@ -69,7 +68,7 @@ class ClientSecurityManager:
             ssl_config = self._create_ssl_config()
             self.ssl_manager = SSLManager(ssl_config)
 
-        logger.info("Client security manager initialized")
+        get_global_logger().info("Client security manager initialized")
 
     def _create_ssl_config(self) -> SSLConfig:
         """Create SSL configuration for client connections."""
@@ -114,13 +113,13 @@ class ClientSecurityManager:
             # Create client SSL context
             context = self.ssl_manager.create_client_context()
 
-            logger.info(
+            get_global_logger().info(
                 f"Client SSL context created for {server_hostname or 'unknown server'}"
             )
             return context
 
         except Exception as e:
-            logger.error(f"Failed to create client SSL context: {e}")
+            get_global_logger().error(f"Failed to create client SSL context: {e}")
             return None
 
     def generate_client_api_key(self, user_id: str, prefix: str = "mcp_proxy") -> str:
@@ -136,10 +135,10 @@ class ClientSecurityManager:
         """
         try:
             api_key = generate_api_key(prefix=prefix)
-            logger.info(f"Generated API key for user: {user_id}")
+            get_global_logger().info(f"Generated API key for user: {user_id}")
             return api_key
         except Exception as e:
-            logger.error(f"Failed to generate API key: {e}")
+            get_global_logger().error(f"Failed to generate API key: {e}")
             raise
 
     def create_client_jwt_token(
@@ -173,11 +172,11 @@ class ClientSecurityManager:
                 expiry_hours=expiry_hours,
             )
 
-            logger.info(f"Created JWT token for user: {user_id}")
+            get_global_logger().info(f"Created JWT token for user: {user_id}")
             return token
 
         except Exception as e:
-            logger.error(f"Failed to create JWT token: {e}")
+            get_global_logger().error(f"Failed to create JWT token: {e}")
             raise
 
     def validate_server_certificate(
@@ -196,26 +195,26 @@ class ClientSecurityManager:
         try:
             # Validate certificate format
             if not validate_certificate_format(cert_path):
-                logger.error(f"Invalid certificate format: {cert_path}")
+                get_global_logger().error(f"Invalid certificate format: {cert_path}")
                 return False
 
             # Validate certificate chain if CA provided
             if ca_cert_path:
                 if not validate_certificate_chain(cert_path, ca_cert_path):
-                    logger.error(f"Invalid certificate chain: {cert_path}")
+                    get_global_logger().error(f"Invalid certificate chain: {cert_path}")
                     return False
 
             # Parse certificate and check basic properties
             cert_info = parse_certificate(cert_path)
             if not cert_info:
-                logger.error(f"Failed to parse certificate: {cert_path}")
+                get_global_logger().error(f"Failed to parse certificate: {cert_path}")
                 return False
 
-            logger.info(f"Server certificate validated: {cert_path}")
+            get_global_logger().info(f"Server certificate validated: {cert_path}")
             return True
 
         except Exception as e:
-            logger.error(f"Failed to validate server certificate: {e}")
+            get_global_logger().error(f"Failed to validate server certificate: {e}")
             return False
 
     def extract_server_roles(self, cert_path: str) -> List[str]:
@@ -230,10 +229,12 @@ class ClientSecurityManager:
         """
         try:
             roles = extract_roles_from_certificate(cert_path)
-            logger.info(f"Extracted roles from server certificate: {roles}")
+            get_global_logger().info(
+                f"Extracted roles from server certificate: {roles}"
+            )
             return roles
         except Exception as e:
-            logger.error(f"Failed to extract roles from certificate: {e}")
+            get_global_logger().error(f"Failed to extract roles from certificate: {e}")
             return []
 
     def get_client_auth_headers(
@@ -271,11 +272,11 @@ class ClientSecurityManager:
             headers["X-Proxy-Type"] = "mcp_proxy_adapter"
             headers["X-Client-Type"] = "proxy_client"
 
-            logger.debug(f"Created auth headers for method: {auth_method}")
+            get_global_logger().debug(f"Created auth headers for method: {auth_method}")
             return headers
 
         except Exception as e:
-            logger.error(f"Failed to create auth headers: {e}")
+            get_global_logger().error(f"Failed to create auth headers: {e}")
             return {}
 
     def prepare_client_connection(
@@ -307,13 +308,13 @@ class ClientSecurityManager:
                 token=server_config.get("token"),
             )
 
-            logger.info(
+            get_global_logger().info(
                 f"Prepared client connection for {server_config.get('hostname', 'unknown')}"
             )
             return ssl_context, auth_headers
 
         except Exception as e:
-            logger.error(f"Failed to prepare client connection: {e}")
+            get_global_logger().error(f"Failed to prepare client connection: {e}")
             return None, {}
 
     def validate_server_response(self, response_headers: Dict[str, str]) -> bool:
@@ -331,23 +332,23 @@ class ClientSecurityManager:
             required_headers = ["Content-Type"]
             for header in required_headers:
                 if header not in response_headers:
-                    logger.warning(f"Missing required header: {header}")
+                    get_global_logger().warning(f"Missing required header: {header}")
 
             # Check for security headers
             security_headers = ["X-Frame-Options", "X-Content-Type-Options"]
             for header in security_headers:
                 if header in response_headers:
-                    logger.debug(f"Found security header: {header}")
+                    get_global_logger().debug(f"Found security header: {header}")
 
             # Validate content type
             content_type = response_headers.get("Content-Type", "")
             if "application/json" not in content_type:
-                logger.warning(f"Unexpected content type: {content_type}")
+                get_global_logger().warning(f"Unexpected content type: {content_type}")
 
             return True
 
         except Exception as e:
-            logger.error(f"Failed to validate server response: {e}")
+            get_global_logger().error(f"Failed to validate server response: {e}")
             return False
 
     def get_client_certificate_info(self) -> Optional[Dict[str, Any]]:
@@ -373,7 +374,7 @@ class ClientSecurityManager:
             return None
 
         except Exception as e:
-            logger.error(f"Failed to get client certificate info: {e}")
+            get_global_logger().error(f"Failed to get client certificate info: {e}")
             return None
 
     def is_ssl_enabled(self) -> bool:
@@ -387,7 +388,7 @@ class ClientSecurityManager:
 
 # Factory function for easy integration
 def create_client_security_manager(
-    config: Dict[str, Any]
+    config: Dict[str, Any],
 ) -> Optional[ClientSecurityManager]:
     """
     Create client security manager instance.
@@ -401,8 +402,10 @@ def create_client_security_manager(
     try:
         return ClientSecurityManager(config)
     except ImportError:
-        logger.warning("mcp_security_framework not available, client security disabled")
+        get_global_logger().warning(
+            "mcp_security_framework not available, client security disabled"
+        )
         return None
     except Exception as e:
-        logger.error(f"Failed to create client security manager: {e}")
+        get_global_logger().error(f"Failed to create client security manager: {e}")
         return None
