@@ -2,7 +2,8 @@
 Module for defining errors and exceptions for the microservice.
 """
 
-from typing import Any, Dict, List, Optional, Union
+from dataclasses import dataclass
+from typing import Any, Dict, List, Optional
 
 
 class MicroserviceError(Exception):
@@ -32,20 +33,17 @@ class MicroserviceError(Exception):
         super().__init__(message)
 
     def to_dict(self) -> Dict[str, Any]:
-        """
-        Converts the error to a dictionary for JSON-RPC response.
-
-        Returns:
-            Dictionary with error information.
-        """
-        result = {"code": self.code, "message": self.message}
-
+        """Convert error to dictionary format."""
+        result = {
+            "code": self.code,
+            "message": self.message
+        }
         if self.data:
             result["data"] = self.data
-
         return result
 
 
+
 class ParseError(MicroserviceError):
     """
     Error while parsing JSON request.
@@ -198,20 +196,81 @@ class TimeoutError(MicroserviceError):
         super().__init__(message, code=-32003, data=data)
 
 
-def format_validation_errors(errors: List[Dict[str, Any]]) -> Dict[str, Any]:
-    """
-    Formats validation errors into a standard format.
 
-    Args:
-        errors: List of validation errors.
 
-    Returns:
-        Formatted validation errors.
-    """
-    formatted_errors = {}
-    for error in errors:
-        loc = error.get("loc", [])
-        field = ".".join(str(item) for item in loc)
-        msg = error.get("msg", "Validation error")
-        formatted_errors[field] = msg
-    return formatted_errors
+@dataclass
+class ValidationResult:
+    """Result of configuration validation."""
+    level: str  # "error", "warning", "info"
+    message: str
+    section: Optional[str] = None
+    key: Optional[str] = None
+    suggestion: Optional[str] = None
+
+
+class ConfigError(MicroserviceError):
+    """Configuration validation error."""
+    
+    def __init__(self, message: str, validation_results: Optional[List[ValidationResult]] = None):
+        """
+        Initialize configuration error.
+        
+        Args:
+            message: Error message
+            validation_results: List of validation results that caused the error
+        """
+        super().__init__(message, code=-32001, data={"type": "configuration_error"})
+        self.validation_results = validation_results or []
+    
+
+
+class MissingConfigKeyError(ConfigError):
+    """Missing required configuration key."""
+    
+    def __init__(self, key: str, section: str = None):
+        location = f"{section}.{key}" if section else key
+        message = f"Required configuration key '{location}' is missing"
+        super().__init__(message)
+        self.key = key
+        self.section = section
+
+
+class InvalidConfigValueError(ConfigError):
+    """Invalid configuration value."""
+    
+    def __init__(self, key: str, value: Any, expected_type: str, section: str = None):
+        location = f"{section}.{key}" if section else key
+        message = f"Invalid value for '{location}': got {type(value).__name__}, expected {expected_type}"
+        super().__init__(message)
+        self.key = key
+        self.section = section
+        self.value = value
+        self.expected_type = expected_type
+
+
+class MissingConfigSectionError(ConfigError):
+    """Missing required configuration section."""
+    
+    def __init__(self, section: str):
+        message = f"Required configuration section '{section}' is missing"
+        super().__init__(message)
+        self.section = section
+
+
+class MissingConfigFileError(ConfigError):
+    """Missing configuration file."""
+    
+    def __init__(self, file_path: str):
+        message = f"Configuration file '{file_path}' does not exist"
+        super().__init__(message)
+        self.file_path = file_path
+
+
+class InvalidConfigFileError(ConfigError):
+    """Invalid configuration file format."""
+    
+    def __init__(self, file_path: str, reason: str):
+        message = f"Invalid configuration file '{file_path}': {reason}"
+        super().__init__(message)
+        self.file_path = file_path
+        self.reason = reason
