@@ -6,10 +6,8 @@ import logging
 import os
 import sys
 import uuid
-from logging.handlers import RotatingFileHandler, TimedRotatingFileHandler
-from typing import Dict, Optional, Any
-
-from mcp_proxy_adapter.config import config
+from logging.handlers import RotatingFileHandler
+from typing import Optional
 
 
 class CustomFormatter(logging.Formatter):
@@ -47,11 +45,6 @@ class RequestContextFilter(logging.Filter):
         super().__init__()
         self.request_id = request_id
 
-    def filter(self, record):
-        # Add request_id attribute to the record
-        record.request_id = self.request_id or "no-request-id"
-        return True
-
 
 class RequestLogger:
     """
@@ -60,7 +53,7 @@ class RequestLogger:
 
     def __init__(self, logger_name: str, request_id: Optional[str] = None):
         """
-        Initialize request logger.
+        Initialize request get_global_logger().
 
         Args:
             logger_name: Logger name.
@@ -69,31 +62,31 @@ class RequestLogger:
         self.logger = logging.getLogger(logger_name)
         self.request_id = request_id or str(uuid.uuid4())
         self.filter = RequestContextFilter(self.request_id)
-        self.logger.addFilter(self.filter)
+        get_global_logger().addFilter(self.filter)
 
     def debug(self, msg: str, *args, **kwargs):
         """Log message with DEBUG level."""
-        self.logger.debug(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().debug(f"[{self.request_id}] {msg}", *args, **kwargs)
 
     def info(self, msg: str, *args, **kwargs):
         """Log message with INFO level."""
-        self.logger.info(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().info(f"[{self.request_id}] {msg}", *args, **kwargs)
 
     def warning(self, msg: str, *args, **kwargs):
         """Log message with WARNING level."""
-        self.logger.warning(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().warning(f"[{self.request_id}] {msg}", *args, **kwargs)
 
     def error(self, msg: str, *args, **kwargs):
         """Log message with ERROR level."""
-        self.logger.error(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().error(f"[{self.request_id}] {msg}", *args, **kwargs)
 
     def exception(self, msg: str, *args, **kwargs):
         """Log exception with traceback."""
-        self.logger.exception(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().exception(f"[{self.request_id}] {msg}", *args, **kwargs)
 
     def critical(self, msg: str, *args, **kwargs):
         """Log message with CRITICAL level."""
-        self.logger.critical(f"[{self.request_id}] {msg}", *args, **kwargs)
+        get_global_logger().critical(f"[{self.request_id}] {msg}", *args, **kwargs)
 
 
 def setup_logging(
@@ -118,48 +111,31 @@ def setup_logging(
         rotation_interval: Interval for rotation. By default, taken from configuration.
 
     Returns:
-        Configured logger.
+        Configured get_global_logger().
     """
-    # Get parameters from configuration if not explicitly specified
-    level = level or config.get("logging.level", "INFO")
+    # Use provided parameters or defaults
+    level = level or "INFO"
+    log_file = log_file
+    rotation_type = rotation_type or "size"
+    log_dir = "./logs"
+    log_file_name = "mcp_proxy_adapter.log"
+    error_log_file = "mcp_proxy_adapter_error.log"
+    access_log_file = "mcp_proxy_adapter_access.log"
 
-    # Check debug level from config if debug is enabled
-    if config.get("debug.enabled", False):
-        debug_level = config.get("debug.level", "INFO")
-        # Use debug level if it's more verbose than the logging level
-        debug_level_num = getattr(logging, debug_level.upper(), logging.INFO)
-        level_num = getattr(logging, level.upper(), logging.INFO)
-        if debug_level_num < level_num:
-            level = debug_level
-            logger.debug(f"Using debug level from config: {debug_level}")
-
-    log_file = log_file or config.get("logging.file")
-    rotation_type = rotation_type or "size"  # Default to size-based rotation
-
-    # Get log directory and file settings from config
-    log_dir = config.get("logging.log_dir", "./logs")
-    log_file_name = config.get("logging.log_file", "mcp_proxy_adapter.log")
-    error_log_file = config.get("logging.error_log_file", "mcp_proxy_adapter_error.log")
-    access_log_file = config.get(
-        "logging.access_log_file", "mcp_proxy_adapter_access.log"
-    )
-
-    # Get rotation settings from config
-    max_file_size_str = config.get("logging.max_file_size", "10MB")
-    backup_count = backup_count or config.get("logging.backup_count", 5)
+    # Get rotation settings
+    max_file_size_str = "10MB"
+    backup_count = backup_count or 5
 
     # Parse max file size (e.g., "10MB" -> 10 * 1024 * 1024)
     max_bytes = max_bytes or _parse_file_size(max_file_size_str)
 
     # Get format settings
-    log_format = config.get(
-        "logging.format", "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
-    )
-    date_format = config.get("logging.date_format", "%Y-%m-%d %H:%M:%S")
+    log_format = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+    date_format = "%Y-%m-%d %H:%M:%S"
 
     # Get output settings
-    console_output = config.get("logging.console_output", True)
-    file_output = config.get("logging.file_output", True)
+    console_output = True
+    file_output = True
 
     # Convert string logging level to constant
     numeric_level = getattr(logging, level.upper(), None)
@@ -227,7 +203,7 @@ def setup_logging(
             logger.addHandler(access_handler)
 
     # Configure loggers for external libraries
-    log_levels = config.get("logging.levels", {})
+    log_levels = {}
     for logger_name, logger_level in log_levels.items():
         lib_logger = logging.getLogger(logger_name)
         lib_logger.setLevel(getattr(logging, logger_level.upper(), logging.INFO))
@@ -262,18 +238,13 @@ def _parse_file_size(size_str) -> int:
         return int(size_str)
 
 
-def get_logger(name: str) -> logging.Logger:
-    """
-    Get a logger with the specified name.
+# Global get_global_logger() for use throughout the application
+# Initialize lazily to avoid import-time errors
+logger = None
 
-    Args:
-        name: Logger name.
-
-    Returns:
-        Configured logger instance.
-    """
-    return logging.getLogger(name)
-
-
-# Global logger for use throughout the application
-logger = setup_logging()
+def get_global_logger():
+    """Get the global logger, initializing it if necessary."""
+    global logger
+    if logger is None:
+        logger = setup_logging()
+    return logger
