@@ -8,9 +8,6 @@ client certificates in mTLS connections.
 import ssl
 import logging
 from typing import Dict, Any, Optional
-from starlette.applications import Starlette
-from starlette.requests import Request
-from starlette.responses import Response
 from starlette.types import ASGIApp, Receive, Send, Scope
 
 logger = logging.getLogger(__name__)
@@ -37,7 +34,7 @@ class MTLSASGIApp:
         self.verify_client = ssl_config.get("verify_client", False)
         self.client_cert_required = ssl_config.get("client_cert_required", False)
 
-        logger.info(
+        get_global_logger().info(
             f"MTLS ASGI app initialized: verify_client={self.verify_client}, "
             f"client_cert_required={self.client_cert_required}"
         )
@@ -58,11 +55,11 @@ class MTLSASGIApp:
                 if client_cert:
                     # Store certificate in scope for middleware access
                     scope["client_certificate"] = client_cert
-                    logger.debug(
+                    get_global_logger().debug(
                         f"Client certificate extracted: {client_cert.get('subject', {})}"
                     )
                 elif self.client_cert_required:
-                    logger.warning("Client certificate required but not provided")
+                    get_global_logger().warning("Client certificate required but not provided")
                     # Return 401 Unauthorized
                     await self._send_unauthorized_response(send)
                     return
@@ -71,7 +68,7 @@ class MTLSASGIApp:
             await self.app(scope, receive, send)
 
         except Exception as e:
-            logger.error(f"Error in MTLS ASGI app: {e}")
+            get_global_logger().error(f"Error in MTLS ASGI app: {e}")
             await self._send_error_response(send, str(e))
 
     def _extract_client_certificate(self, scope: Scope) -> Optional[Dict[str, Any]]:
@@ -97,7 +94,7 @@ class MTLSASGIApp:
             return None
 
         except Exception as e:
-            logger.error(f"Failed to extract client certificate: {e}")
+            get_global_logger().error(f"Failed to extract client certificate: {e}")
             return None
 
     async def _send_unauthorized_response(self, send: Send) -> None:
@@ -141,20 +138,3 @@ class MTLSASGIApp:
         await send({"type": "http.response.body", "body": body})
 
 
-def create_mtls_asgi_app(app: ASGIApp, ssl_config: Dict[str, Any]) -> ASGIApp:
-    """
-    Create MTLS-enabled ASGI application.
-
-    Args:
-        app: The underlying ASGI application (FastAPI)
-        ssl_config: SSL configuration for mTLS
-
-    Returns:
-        MTLS-enabled ASGI application
-    """
-    if ssl_config.get("mode") == "mtls" or ssl_config.get("verify_client", False):
-        logger.info("Creating MTLS-enabled ASGI application")
-        return MTLSASGIApp(app, ssl_config)
-    else:
-        logger.info("Creating standard ASGI application (no mTLS)")
-        return app
