@@ -37,7 +37,7 @@ class MTLSASGIApp:
         self.ssl_config = ssl_config
         self.client_cert_required = ssl_config.get("client_cert_required", True)
 
-        logger.info(
+        get_global_logger().info(
             f"MTLS ASGI app initialized: client_cert_required={self.client_cert_required}"
         )
 
@@ -57,11 +57,11 @@ class MTLSASGIApp:
                 if client_cert:
                     # Store certificate in scope for middleware access
                     scope["client_certificate"] = client_cert
-                    logger.debug(
+                    get_global_logger().debug(
                         f"Client certificate extracted: {client_cert.get('subject', {})}"
                     )
                 elif self.client_cert_required:
-                    logger.warning("Client certificate required but not provided")
+                    get_global_logger().warning("Client certificate required but not provided")
                     # Return 401 Unauthorized
                     await self._send_unauthorized_response(send)
                     return
@@ -70,7 +70,7 @@ class MTLSASGIApp:
             await self.app(scope, receive, send)
 
         except Exception as e:
-            logger.error(f"Error in MTLS ASGI app: {e}")
+            get_global_logger().error(f"Error in MTLS ASGI app: {e}")
             await self._send_error_response(send, str(e))
 
     def _extract_client_certificate(
@@ -88,7 +88,7 @@ class MTLSASGIApp:
         try:
             ssl_context = scope.get("ssl")
             if not ssl_context:
-                logger.debug("No SSL context found in scope")
+                get_global_logger().debug("No SSL context found in scope")
                 return None
 
             # Try to get peer certificate
@@ -99,14 +99,14 @@ class MTLSASGIApp:
                     cert = x509.load_der_x509_certificate(cert_data)
                     return self._cert_to_dict(cert)
                 else:
-                    logger.debug("No certificate data in SSL context")
+                    get_global_logger().debug("No certificate data in SSL context")
                     return None
             else:
-                logger.debug("SSL context has no getpeercert method")
+                get_global_logger().debug("SSL context has no getpeercert method")
                 return None
 
         except Exception as e:
-            logger.error(f"Failed to extract client certificate: {e}")
+            get_global_logger().error(f"Failed to extract client certificate: {e}")
             return None
 
     def _cert_to_dict(self, cert: x509.Certificate) -> Dict[str, Any]:
@@ -152,7 +152,7 @@ class MTLSASGIApp:
                 },
             }
         except Exception as e:
-            logger.error(f"Failed to convert certificate to dict: {e}")
+            get_global_logger().error(f"Failed to convert certificate to dict: {e}")
             return {"error": str(e)}
 
     async def _send_unauthorized_response(self, send):
@@ -185,15 +185,3 @@ class MTLSASGIApp:
         await send({"type": "http.response.body", "body": body})
 
 
-def create_mtls_asgi_app(app, ssl_config: Dict[str, Any]):
-    """
-    Create MTLS ASGI application wrapper.
-
-    Args:
-        app: The underlying ASGI application
-        ssl_config: SSL configuration dictionary
-
-    Returns:
-        MTLS ASGI app wrapper
-    """
-    return MTLSASGIApp(app, ssl_config)
