@@ -12,7 +12,6 @@ mutual TLS. Designed to be used by services built on this framework to:
 This client intentionally avoids framework-specific configuration objects and
 accepts explicit parameters for clarity and portability.
 """
-from __future__ import annotations
 
 import json
 import ssl
@@ -49,7 +48,7 @@ class ProxyClient:
 
     Usage:
         async with ProxyClient(
-            base_url="https://127.0.0.1:3004",
+            base_url="https://your-proxy-host:3004",
             ca_cert_path="/path/to/ca.crt",
             client_cert_path="/path/to/client.crt",
             client_key_path="/path/to/client.key",
