@@ -10,9 +10,9 @@ email: vasilyvz@gmail.com
 
 import logging
 from typing import Dict, Any, Optional
-from pathlib import Path
 
 from .server_engine import ServerEngineFactory, ServerEngine
+from .logging import get_global_logger
 
 logger = logging.getLogger(__name__)
 
@@ -41,13 +41,13 @@ class ServerConfigAdapter:
         """
         engine = ServerEngineFactory.get_engine(target_engine)
         if not engine:
-            logger.error(f"Unknown server engine: {target_engine}")
+            get_global_logger().error(f"Unknown server engine: {target_engine}")
             return {}
 
         if target_engine == "hypercorn":
             return ServerConfigAdapter._convert_to_hypercorn_ssl(ssl_config)
         else:
-            logger.warning(f"No SSL conversion available for engine: {target_engine}")
+            get_global_logger().warning(f"No SSL conversion available for engine: {target_engine}")
             return {}
 
     @staticmethod
@@ -71,24 +71,10 @@ class ServerConfigAdapter:
         if "chk_hostname" in ssl_config:
             hypercorn_ssl["check_hostname"] = ssl_config["chk_hostname"]
 
-        logger.debug(f"Converted SSL config to hypercorn: {hypercorn_ssl}")
+        get_global_logger().debug(f"Converted SSL config to hypercorn: {hypercorn_ssl}")
         return hypercorn_ssl
 
     @staticmethod
-    def get_optimal_engine_for_config(config: Dict[str, Any]) -> Optional[str]:
-        """
-        Determine the optimal server engine for a given configuration.
-
-        Currently only hypercorn is supported.
-
-        Args:
-            config: Server configuration
-
-        Returns:
-            Optimal engine name (currently always "hypercorn")
-        """
-        # Currently only hypercorn is supported
-        return "hypercorn"
 
     @staticmethod
     def validate_engine_compatibility(config: Dict[str, Any], engine_name: str) -> bool:
@@ -104,7 +90,7 @@ class ServerConfigAdapter:
         """
         engine = ServerEngineFactory.get_engine(engine_name)
         if not engine:
-            logger.error(f"Unknown engine: {engine_name}")
+            get_global_logger().error(f"Unknown engine: {engine_name}")
             return False
 
         # Check SSL requirements
@@ -115,7 +101,7 @@ class ServerConfigAdapter:
 
         if ssl_config.get("verify_client", False):
             if not engine.get_supported_features().get("mtls_client_certs", False):
-                logger.error(
+                get_global_logger().error(
                     f"Engine {engine_name} doesn't support mTLS client certificates"
                 )
                 return False
@@ -163,8 +149,8 @@ class UnifiedServerRunner:
         self.default_engine = default_engine
         self.available_engines = ServerEngineFactory.get_available_engines()
 
-        logger.info(f"Available engines: {list(self.available_engines.keys())}")
-        logger.info(f"Default engine: {default_engine}")
+        get_global_logger().info(f"Available engines: {list(self.available_engines.keys())}")
+        get_global_logger().info(f"Default engine: {default_engine}")
 
     def run_server(
         self, app: Any, config: Dict[str, Any], engine_name: Optional[str] = None
@@ -179,7 +165,7 @@ class UnifiedServerRunner:
         """
         # Use hypercorn as the only supported engine
         selected_engine = "hypercorn"
-        logger.info(f"Using hypercorn engine")
+        get_global_logger().info(f"Using hypercorn engine")
 
         # Validate compatibility
         if not ServerConfigAdapter.validate_engine_compatibility(
@@ -198,16 +184,16 @@ class UnifiedServerRunner:
         converted_config = self._prepare_config_for_engine(config, selected_engine)
 
         # Run server
-        logger.info(f"Starting server with {selected_engine} engine")
+        get_global_logger().info(f"Starting server with {selected_engine} engine")
         engine.run_server(app, converted_config)
 
     def _prepare_config_for_engine(
         self, config: Dict[str, Any], engine_name: str
     ) -> Dict[str, Any]:
-        logger.info(
+        get_global_logger().info(
             f"🔍 Debug: _prepare_config_for_engine called with config keys: {list(config.keys())}"
         )
-        logger.info(f"🔍 Debug: SSL config in input: {config.get('ssl', 'NOT_FOUND')}")
+        get_global_logger().info(f"🔍 Debug: SSL config in input: {config.get('ssl', 'NOT_FOUND')}")
         """
         Prepare configuration for a specific engine.
         
@@ -234,7 +220,7 @@ class UnifiedServerRunner:
             or "ca_certs" in config
             or "verify_mode" in config
         ):
-            logger.info(f"🔍 DEBUG: Direct SSL parameters found in config")
+            get_global_logger().info(f"🔍 DEBUG: Direct SSL parameters found in config")
             if "certfile" in config:
                 engine_config["certfile"] = config["certfile"]
             if "keyfile" in config:
@@ -262,29 +248,4 @@ class UnifiedServerRunner:
 
         return engine_config
 
-    def get_engine_info(self, engine_name: str) -> Dict[str, Any]:
-        """
-        Get information about a specific engine.
 
-        Args:
-            engine_name: Name of the engine
-
-        Returns:
-            Engine information dictionary
-        """
-        return ServerConfigAdapter.get_engine_capabilities(engine_name)
-
-    def list_available_engines(self) -> Dict[str, Dict[str, Any]]:
-        """
-        List all available engines with their capabilities.
-
-        Returns:
-            Dictionary mapping engine names to their capabilities
-        """
-        engines_info = {}
-        for name, engine in self.available_engines.items():
-            engines_info[name] = {
-                "features": engine.get_supported_features(),
-                "config_schema": engine.get_config_schema(),
-            }
-        return engines_info
