@@ -25,27 +25,26 @@ def main():
     parser.add_argument("--port", type=int, help="Server port")
     parser.add_argument("--debug", action="store_true", help="Enable debug mode")
     args = parser.parse_args()
-    # Override configuration if specified
-    config_overrides = {}
-    if args.host:
-        config_overrides["host"] = args.host
-    if args.port:
-        config_overrides["port"] = args.port
-    if args.debug:
-        config_overrides["debug"] = True
     print(f"🚀 Starting Basic Framework Example")
     print(f"📋 Configuration: {args.config}")
+    if args.host:
+        print(f"🌐 Host override: {args.host}")
+    if args.port:
+        print(f"🔌 Port override: {args.port}")
+    if args.debug:
+        print(f"🔧 Debug mode: enabled")
     print("=" * 50)
-    # Use the factory method to create and run the server
+    
+    # Note: Host and port overrides should be handled in configuration file
+    # or by modifying the configuration before passing to create_and_run_server
     import asyncio
     asyncio.run(create_and_run_server(
         config_path=args.config,
         title="Basic Framework Example",
         description="Basic MCP Proxy Adapter with minimal configuration",
         version="1.0.0",
-        host=config_overrides.get("host"),
-        port=config_overrides.get("port"),
-        debug=config_overrides.get("debug", False),
+        host=args.host or "0.0.0.0",
+        log_level="debug" if args.debug else "info"
     ))
 
 
