@@ -9,12 +9,10 @@ email: vasilyvz@gmail.com
 import asyncio
 import json
 import os
-import signal
 import subprocess
 import sys
 import time
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple
 
 # Add project root to path
 project_root = Path(__file__).parent.parent.parent
@@ -404,31 +402,6 @@ class SecurityTestRunner:
         
         return passed_tests == total_tests
 
-    def print_summary(self):
-        """Print test summary."""
-        if not self.test_results:
-            print("📊 No test results to display")
-            return
-            
-        total_tests = len(self.test_results)
-        passed_tests = sum(1 for result in self.test_results if result.success)
-        
-        print("\n" + "=" * 50)
-        print("📊 TEST SUMMARY")
-        print("=" * 50)
-        print(f"Total tests: {total_tests}")
-        print(f"Passed: {passed_tests}")
-        print(f"Failed: {total_tests - passed_tests}")
-        print(f"Success rate: {(passed_tests/total_tests)*100:.1f}%")
-        
-        if total_tests - passed_tests > 0:
-            print(f"\n📋 DETAILED RESULTS")
-            print("-" * 30)
-            for result in self.test_results:
-                status = "✅ PASS" if result.success else "❌ FAIL"
-                print(f"{status} {result.test_name}")
-                if not result.success and result.error_message:
-                    print(f"   Error: {result.error_message}")
 
 
 async def main():
