@@ -12,12 +12,9 @@ import json
 import os
 import ssl
 import time
-from typing import Dict, Any, Optional, List, Union
-from urllib.parse import urljoin
 from pathlib import Path
 import aiohttp
 import requests
-from requests.exceptions import RequestException
 
 # Import security framework components
 try:
@@ -27,16 +24,13 @@ try:
         CertificateManager,
         PermissionManager,
     )
-    from mcp_security_framework.utils import (
         generate_api_key,
         create_jwt_token,
         validate_jwt_token,
     )
-    from mcp_security_framework.utils import (
         extract_roles_from_cert,
         validate_certificate_chain,
     )
-    from mcp_security_framework.utils import (
         create_ssl_context,
         validate_server_certificate,
     )
